Object subclass: #OperaAbstractConnector
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Opera-Connector'!

!OperaAbstractConnector methodsFor: 'actions' stamp: 'MU 9/11/2002 23:44'!
send: anOperaRemoteMessage to: host port: port 
	| ret |
	ret := nil.
	self processArguments: anOperaRemoteMessage arguments.
	[ret := OperaPortableUtil
				soapSend: anOperaRemoteMessage
				host: host
				port: port
				transport: self transport]
		on: Error
		do: [:ex | 
			ex name = #SocketError
				ifTrue: [OperaError cannotConnect tag: 'cannot connect to server > host: ' , host , 'port: ' , port printString;
						 signal].
			ex name = #SocketTimeout
				ifTrue: [OperaError responceTimeout tag: 'from > host: ' , host , 'port: ' , port printString;
						 signal].
			ex pass].
	^ self processReturn: ret! !


!OperaAbstractConnector methodsFor: 'protected' stamp: 'MU 2/28/2002 16:30'!
processArguments: aCollectionOfArguments
	"##needs more work##"
	"currently obj ref argument is always registerd in root ooa"
	aCollectionOfArguments do:[:each |
		(OperaObjectReference hasInstance: each)
			ifTrue:[ OperaORB root registerObjectImplFor: each.
					"passing obj ref to server, so impl should be nil"
					each impl: nil.
			]
	].
	^aCollectionOfArguments! !

!OperaAbstractConnector methodsFor: 'protected' stamp: 'MU 2/24/2002 00:52'!
processReturn: anObject
	| obj |
	obj := anObject.
	obj class name == #OperaObjectReference ifTrue: [obj := obj asRemoteObject].
	"sort of obj ref support"
	^ obj! !

!OperaAbstractConnector methodsFor: 'protected' stamp: 'MU 9/11/2002 23:44'!
transport
	^self subclassResponsibility! !


OperaAbstractConnector subclass: #OperaColocationConnector
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Opera-Connector'!

!OperaColocationConnector methodsFor: 'actions' stamp: 'MU 2/22/2002 00:56'!
send: anOperaRemoteMessage to: host port: port 
	^anOperaRemoteMessage class name == #OperaRemoteMessage
		ifTrue: [OperaObjectAdapter root dispatch: anOperaRemoteMessage]
		ifFalse: [OperaImplError signal: 'anOperaRemoteMessage is nil' type: #InvalidOperaRemoteMessage]! !


OperaAbstractConnector subclass: #OperaConnector
	instanceVariableNames: 'delegate '
	classVariableNames: 'ConnectorDict '
	poolDictionaries: ''
	category: 'Opera-Connector'!

!OperaConnector methodsFor: 'private'!
connectorNamed: aSymbol
	^self class named: aSymbol! !

!OperaConnector methodsFor: 'private' stamp: 'MU 2/18/2002 01:06'!
isLocal: host port: port 
	^ OperaPortableUtil isLocal: host port: port ! !


!OperaConnector methodsFor: 'accessing' stamp: 'MU 2/22/2002 00:42'!
delegate
	^delegate! !


!OperaConnector methodsFor: 'actions' stamp: 'MU 9/11/2002 23:30'!
send: anOperaRemoteMessage to: host port: port 
	delegate := (self useColocation
					and: [self isLocal: host port: port])
				ifTrue: [self connectorNamed: #local]
				ifFalse: [self connectorNamed: (OperaSetting defaultTransport)].
	^ delegate
		send: anOperaRemoteMessage
		to: host
		port: port! !


!OperaConnector methodsFor: 'setting' stamp: 'MU 2/22/2002 00:37'!
useColocation
	^self class useColocation! !


!OperaConnector methodsFor: 'printing' stamp: 'MU 2/23/2002 23:27'!
printOn: aStream
	super printOn: aStream.
	aStream nextPutAll: '[ ', self delegate printString, ' ]'.! !

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

OperaConnector class
	instanceVariableNames: 'default useColocation '!

!OperaConnector class methodsFor: 'class initialization' stamp: 'MU 2/22/2002 00:21'!
initialize
	"OperaConnector initialize"
	default := self new.
	self installConnectors! !

!OperaConnector class methodsFor: 'class initialization' stamp: 'MU 9/11/2002 23:47'!
installConnectors
	"OperaConnector installConnectors"
	ConnectorDict := IdentityDictionary new.
	self regsiter: OperaHttpConnector new named: #http.
	self regsiter: OperaSqtpConnector new named: #sqtp.
	self regsiter: OperaColocationConnector new named: #local.
	! !


!OperaConnector class methodsFor: 'actions'!
named: aSymbol
	^ConnectorDict at: aSymbol! !

!OperaConnector class methodsFor: 'actions' stamp: 'MU 9/11/2002 23:25'!
regsiter: anOperaConnector named: aSymbol
	^ConnectorDict at: aSymbol asSymbol put: anOperaConnector! !

!OperaConnector class methodsFor: 'actions' stamp: 'MU 9/11/2002 23:25'!
unregsiterNamed: aSymbol
	^ConnectorDict removeKey: aSymbol asSymbol ! !


!OperaConnector class methodsFor: 'accessing' stamp: 'MU 2/22/2002 00:20'!
default
	^default! !


!OperaConnector class methodsFor: 'setting' stamp: 'MU 2/22/2002 00:37'!
useColocation
	useColocation isNil ifTrue: [useColocation := false].
	^useColocation! !

!OperaConnector class methodsFor: 'setting' stamp: 'MU 2/22/2002 00:37'!
useColocation: aBoolean
	"OperaConnector useColocation: true"
	useColocation := aBoolean! !


OperaAbstractConnector subclass: #OperaHttpConnector
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Opera-Connector'!

!OperaHttpConnector methodsFor: 'protected' stamp: 'MU 9/11/2002 23:45'!
transport
	^#http! !


OperaAbstractConnector subclass: #OperaSqtpConnector
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Opera-Connector'!

!OperaSqtpConnector methodsFor: 'protected' stamp: 'MU 9/11/2002 23:45'!
transport
	^#sqtp! !

OperaConnector initialize!