SoapImplError subclass: #SoapContentTypeMismatch
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-Http-Client'!


SoapAbstractSocketClient subclass: #SoapHttpClient
	instanceVariableNames: 'specifiedServer soapEnvelopeString headerString bodyString contents soapAction proxyPort proxyServer '
	classVariableNames: 'CrLf '
	poolDictionaries: ''
	category: 'SOAP-Http-Client'!

!SoapHttpClient methodsFor: 'initialize-release' stamp: 'MU 8/18/2002 17:27'!
host: hostnameString port: portNumberInteger page: pageString 
	
	host := hostnameString.
	port := portNumberInteger.
	reqURI := (pageString isNil
					or: [pageString isEmpty])
				ifTrue: ['/']
				ifFalse: [pageString].
	

	specifiedServer := host , ':' , port printString.
	self proxyServer
		ifNotNil: [reqURI := 'http://' , host , ':' , port printString , reqURI.
			"put back together"
			host := self proxyServer.
			port := self proxyPort]! !

!SoapHttpClient methodsFor: 'initialize-release' stamp: 'MU 8/18/2002 19:46'!
parseURL: anUrlString 
	| url bare frm |
	url := anUrlString.
	bare := (url asLowercase beginsWith: 'http://')
				ifTrue: [url copyFrom: 8 to: url size]
				ifFalse: [url].
	host := bare copyUpTo: $/.
	specifiedServer := host.
	(host includes: $:)
		ifTrue: [port := (host copyFrom: (host indexOf: $:)
							+ 1 to: host size) asNumber.
			host := host copyUpTo: $:]
		ifFalse: [port := self defaultPort].
	(frm := (bare indexOf: $/) ) = 0 ifTrue:[frm := 1].
	reqURI := bare
				copyFrom: frm
				to: bare size.
	(reqURI size = 0 or: [reqURI = specifiedServer])
		ifTrue: [reqURI := '/'].
	self proxyServer
		ifNotNil: [reqURI := 'http://' , host , ':' , port printString , reqURI.
			"put back together"
			host := self proxyServer.
			port := self proxyPort]! !


!SoapHttpClient methodsFor: 'actions'!
send: soapEnvelopeOrSrting action: aSoapAction 
	self soapAction: aSoapAction.
	^self send: soapEnvelopeOrSrting! !


!SoapHttpClient methodsFor: 'private'!
redirectWith: responseCode
	| newUrl |
	newUrl := socket getHeader: 'location'.
	socket destroy.
	newUrl
		ifNotNil: [self class showLog
				ifTrue: [Transcript show: ' redirecting to: ' , newUrl].
			^ (self class url: newUrl)
				send: soapEnvelopeString
				action: soapAction].
	
	^SoapHttpGenericError signal: 'failed to redirect by no ''location'' header' code: responseCode contents: contents! !

!SoapHttpClient methodsFor: 'private' stamp: 'MU 8/18/2002 20:15'!
signalHttpErrorWith: responseCode

	^SoapHttpGenericError signal: '' code: responseCode contents: contents! !


!SoapHttpClient methodsFor: 'accessing' stamp: 'MU 8/8/2002 23:05'!
proxyPort

	proxyPort isNil ifTrue: [proxyPort := self class proxyPort].
	^proxyPort! !

!SoapHttpClient methodsFor: 'accessing' stamp: 'MU 8/8/2002 23:06'!
proxyServer

	proxyServer isNil ifTrue: [proxyServer := self class proxyServer].
	^proxyServer! !

!SoapHttpClient methodsFor: 'accessing'!
soapAction
	soapAction isNil ifTrue: [soapAction := SoapAction noIntent].
	^soapAction! !

!SoapHttpClient methodsFor: 'accessing' stamp: 'mu 12/7/2001 01:12'!
soapAction: aValue

	soapAction := aValue! !

!SoapHttpClient methodsFor: 'accessing' stamp: 'mu 12/6/2001 01:42'!
specifiedServer

	^specifiedServer! !

!SoapHttpClient methodsFor: 'accessing' stamp: 'mu 12/6/2001 01:42'!
specifiedServer: aValue

	specifiedServer := aValue! !


!SoapHttpClient methodsFor: 'constants' stamp: 'mu 12/7/2001 01:39'!
defaultPort
	^self class defaultPort! !


!SoapHttpClient methodsFor: 'actions-hooks' stamp: 'MU 4/18/2003 16:07'!
getResponseContents
	
	| list header firstData length aStream responseCode responseCodeKind type |
	list := socket getResponseUpTo: CrLf, CrLf ignoring: (String with: Character cr).	"list = header, CrLf, CrLf, beginningOfData"
	header := list at: 1.
	firstData := list at: 3.
	(socket isConnected not and: [header isEmpty]) ifTrue: [SoapCannotConnectToServer signal: 'Server does not respond - ''host: ', host , ' port: ', port printString].
	
	self class showLog ifTrue: [Transcript cr; cr; show: 'Got following header response:'; 	cr; show: header.].

	"dig out some headers"
	socket header: header.
	length := socket getHeader: 'content-length'.
	length ifNotNil: [ length := length asNumber ].
	aStream := socket getRestOfBuffer: firstData totalLength: length.
	contents := aStream contents.
	
	responseCode := socket responseCode.
	responseCodeKind := responseCode first.
	responseCodeKind = $3 ifTrue: [^self redirectWith: responseCode].
	(responseCodeKind = $4 or: [responseCodeKind = $5]) ifTrue: [socket destroy. ^self signalHttpErrorWith: responseCode].
	
	type := socket getHeader: 'content-type'.
	type isNil ifTrue: [type := ''].
	(((type beginsWith: 'text/xml') not) and: [responseCodeKind = $2]) 
		ifTrue: [socket destroy. ^SoapContentTypeMismatch signal: 'Wrong type: ', type ,' It should be text/xml'].

	^contents ! !

!SoapHttpClient methodsFor: 'actions-hooks'!
prepareAdditionals
	
	headerString := String
				streamContents: [:str | 
					str nextPutAll: 'POST ' , reqURI , ' HTTP/1.0'; nextPutAll: CrLf.
					str nextPutAll: 'Host: ' , specifiedServer; nextPutAll: CrLf.
					str nextPutAll: 'User-Agent: Squeak 3.2'; nextPutAll: CrLf.
					str nextPutAll: 'Content-length: ', (bodyString size-1) printString; nextPutAll: CrLf.
					str nextPutAll: 'Content-type: text/xml; charset="utf-8"'; nextPutAll: CrLf.
					str nextPutAll: self soapAction printString; nextPutAll: CrLf.].
	
	self class showLog ifTrue: [
		Transcript 
			cr; cr; show: 'Sending following header:';
			cr; show: headerString.]! !

!SoapHttpClient methodsFor: 'actions-hooks'!
prepareEnvelope: soapEnvelopeOrString
	
	soapEnvelopeString := soapEnvelopeOrString isString ifTrue: [ soapEnvelopeOrString ] ifFalse: [soapEnvelopeOrString printXmlString].
	
	bodyString := SoXmlUtil contentsWithXmlDeclaration: soapEnvelopeString.
! !

!SoapHttpClient methodsFor: 'actions-hooks' stamp: 'MU 4/18/2003 16:07'!
prepareSocket
	socket := HTTPSocket new.
	socket connectTo: serverAddress port: port.
	socket
		waitForConnectionUntil: (Socket deadlineSecs: self class connectionTimeout).
	socket isConnected
		ifFalse: [SoapCannotConnectToServer signal: 'Server does not respond - ''host: ' , host , ' port: ' , port printString]! !

!SoapHttpClient methodsFor: 'actions-hooks'!
sendBySocket

	socket sendData: headerString.
	socket sendData: bodyString.! !

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

SoapHttpClient class
	instanceVariableNames: ''!

!SoapHttpClient class methodsFor: 'class initialization' stamp: 'MU 8/8/2002 23:06'!
initialize
	"SoapHttpClient initialize"
	showLog := false.

	CrLf := String with: Character cr with: Character lf.
	
	! !


!SoapHttpClient class methodsFor: 'instance creation' stamp: 'mu 12/19/2001 00:17'!
host: hostnameString page: pageString
	^ self host: hostnameString port: self defaultPort page: pageString! !

!SoapHttpClient class methodsFor: 'instance creation' stamp: 'MU 8/18/2002 17:27'!
host: hostnameString port: portNumberInteger page: pageString 
	
	^ self new
		host: hostnameString
		port: portNumberInteger
		page: pageString! !

!SoapHttpClient class methodsFor: 'instance creation' stamp: 'mu 12/7/2001 01:23'!
url: urlString
	^self new parseURL: urlString! !


!SoapHttpClient class methodsFor: 'constants' stamp: 'mu 12/7/2001 01:39'!
defaultPort
	"default port to connect on"
	^80! !


!SoapHttpClient class methodsFor: 'accessing' stamp: 'MU 8/8/2002 23:02'!
proxyPort
	^HTTPSocket classPool at: #HTTPProxyPort! !

!SoapHttpClient class methodsFor: 'accessing' stamp: 'MU 8/8/2002 23:01'!
proxyServer
	^HTTPSocket classPool at: #HTTPProxyServer! !


SoapAbstractConnector subclass: #SoapHttpConnector
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-Http-Client'!

!SoapHttpConnector methodsFor: 'actions' stamp: 'MU 4/18/2003 16:08'!
send: aSoapEnvelope to: anSoapTcpLocator with: aSoapContext 
	"return aSoapMessage or nil"
	| page soapClient envBuilder rawString returnEnvelope message |
	self debugSend: aSoapEnvelope to: anSoapTcpLocator with: aSoapContext.
	page := aSoapContext targetObjectURI.
	soapClient := SoapHttpClient
				host: anSoapTcpLocator host
				port: anSoapTcpLocator port
				page: page.
	envBuilder := self envelopeBuilder.
	[[rawString := soapClient send: aSoapEnvelope printXmlString action: aSoapContext soapAction.
	returnEnvelope := envBuilder buildSoapEnvelopeFromXmlString: rawString]
		on: SoapHttpGenericError
		do: [:ex | ex errorCode = '500'
				ifTrue: [returnEnvelope :=  envBuilder buildSoapEnvelopeFromXmlString: (ex errorContents)] ifFalse: [ex pass]]]
		on: SoapCannotResolveServer , SoapCannotConnectToServer
		do: [:ex | returnEnvelope := envBuilder buildClientSoapFaultEnvelope: ex].
	message := SoapMessage envelope: returnEnvelope.
	self debugReturn: message.
	^message! !

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

SoapHttpConnector class
	instanceVariableNames: ''!

!SoapHttpConnector class methodsFor: 'class initialization' stamp: 'MU 10/5/2002 02:32'!
initialize
	self initializeAfterLoad! !


!SoapHttpConnector class methodsFor: 'constants' stamp: 'mu 8/28/2002 17:03'!
transportName
	^#http! !


SoapImplError subclass: #SoapHttpGenericError
	instanceVariableNames: 'errorCode errorContents '
	classVariableNames: 'ResultMessageTable '
	poolDictionaries: ''
	category: 'SOAP-Http-Client'!

!SoapHttpGenericError methodsFor: 'exceptionDescription' stamp: 'MU 8/18/2002 20:38'!
description
	"Return a textual description of the exception."

	| desc httpErrorDesc mt |
	desc := self class name asString.
	httpErrorDesc := self errorCode printString, ' ', (ResultMessageTable at: self errorCode ifAbsent:['']).
	desc := desc, ': ', httpErrorDesc.
	^(mt := self messageText) == nil
		ifTrue: [desc]
		ifFalse: [desc, ': ', mt]! !


!SoapHttpGenericError methodsFor: 'accessing' stamp: 'MU 8/18/2002 19:51'!
errorCode
	^errorCode! !

!SoapHttpGenericError methodsFor: 'accessing' stamp: 'MU 8/18/2002 19:51'!
errorCode: anInteger
	errorCode := anInteger! !

!SoapHttpGenericError methodsFor: 'accessing' stamp: 'MU 8/18/2002 20:12'!
errorContents
	^errorContents! !

!SoapHttpGenericError methodsFor: 'accessing' stamp: 'MU 8/18/2002 20:12'!
errorContents: anInteger
	errorContents := anInteger! !

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

SoapHttpGenericError class
	instanceVariableNames: ''!

!SoapHttpGenericError class methodsFor: 'class initialization' stamp: 'MU 8/19/2002 23:02'!
initResultMessageTable
	"SoapHttpGenericError initResultMessageTable"
	ResultMessageTable := Dictionary new.
	ResultMessageTable at: '300' put: 'Multiple Choices'.
	ResultMessageTable at: '301' put: 'Moved Permanently'.
	ResultMessageTable at: '302' put: 'Moved Temporarily'.
	ResultMessageTable at: '303' put: 'See Other'.
	ResultMessageTable at: '304' put: 'Not Modified'.
	ResultMessageTable at: '305' put: 'Use Proxy'.
	ResultMessageTable at: '400' put: 'Bad Request'.
	ResultMessageTable at: '401' put: 'Unauthorized'.
	ResultMessageTable at: '402' put: 'Payment Required'.
	ResultMessageTable at: '403' put: 'Forbidden'.
	ResultMessageTable at: '404' put: 'Not Found'.
	ResultMessageTable at: '405' put: 'Method Not Allowed'.
	ResultMessageTable at: '406' put: 'Not Acceptable'.
	ResultMessageTable at: '407' put: 'Bad Request'.
	ResultMessageTable at: '408' put: 'Request Time-out'.
	ResultMessageTable at: '409' put: 'Conflict'.
	ResultMessageTable at: '410' put: 'Gone'.
	ResultMessageTable at: '411' put: 'Length Required'.
	ResultMessageTable at: '412' put: 'Precondition Failed'.
	ResultMessageTable at: '413' put: 'Request Entity Too Large'.
	ResultMessageTable at: '414' put: 'Request-URI Too Large'.
	ResultMessageTable at: '415' put: 'Unsupported Media Type'.
	ResultMessageTable at: '500' put: 'Internal Server Error'.
	ResultMessageTable at: '501' put: 'Not Implemented'.
	ResultMessageTable at: '502' put: 'Bad Gateway'.
	ResultMessageTable at: '503' put: 'Service Unavailable'.
	ResultMessageTable at: '504' put: 'Gateway Time-out'.
	ResultMessageTable at: '505' put: 'HTTP Version not supported'! !

!SoapHttpGenericError class methodsFor: 'class initialization' stamp: 'MU 8/19/2002 22:59'!
initialize
	"SoapHttpGenericError initialize"
	self initResultMessageTable! !


!SoapHttpGenericError class methodsFor: 'instance creation' stamp: 'MU 8/18/2002 20:39'!
signal: messageText code: errorCode contents: contents 
	^ self new errorCode: errorCode;
		 errorContents: contents;
		 signal: messageText! !

SoapHttpClient initialize!
SoapHttpConnector initialize!
SoapHttpGenericError initialize! 