Object subclass: #SoapHttpModule
	instanceVariableNames: 'envelopeBuilder '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-Http-Comanche'!

!SoapHttpModule methodsFor: 'processing' stamp: 'mu 5/2/2003 18:48'!
process: request
	| rawXml soapContext soapEnvelope returnEnvelope returnXml |
	
	(request contentType = MIMEDocument contentTypeXml)
		ifFalse:[Transcript cr; show: '##Content type is not text/xml: ',  request contentType printString. ^nil].
	rawXml := request stream next: request contentLength. "body"

	self class showLog ifTrue: [Transcript cr; show: '##' , super printString ,' Server:Request:{ ', rawXml printString, '} '. ].
	
	soapContext := SoapContext new.
	soapContext targetObjectURI: request url. "maybe method namespace"
	soapContext soapAction: (SoapAction intent: (request header at: 'soapaction' ifAbsent:[])).
	
	soapEnvelope := self envelopeBuilder buildSoapEnvelopeFromXmlString: rawXml.
	
	 returnEnvelope := soapEnvelope hasFault 
		ifTrue: [ soapEnvelope ] 
		ifFalse: [ SoapServiceHandler default dispatch: soapEnvelope with: soapContext.].

	returnXml := SoXmlUtil contentsWithXmlDeclaration: returnEnvelope printXmlString.
	
	self class showLog ifTrue: [Transcript cr; show: '##' , super printString ,' Server:Return:{ ', returnXml printString, '} '. ].
	
	^HttpResponse fromMIMEDocument: 
		(MIMEDocument contentType: 'text/xml' content: returnXml)
	
	
	
	! !


!SoapHttpModule methodsFor: 'accessing' stamp: 'mu 12/27/2001 23:59'!
envelopeBuilder
	envelopeBuilder isNil ifTrue: [envelopeBuilder := SoapEnvelopeBuilder new].
	^envelopeBuilder! !

!SoapHttpModule methodsFor: 'accessing' stamp: 'mu 12/27/2001 23:59'!
envelopeBuilder: aValue

	envelopeBuilder := aValue! !

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

SoapHttpModule class
	instanceVariableNames: 'showLog useTestServiceHandler '!

!SoapHttpModule class methodsFor: 'class initialization'!
initialize
	"SoapHttpModule initialize"
	debugMode := false! !


!SoapHttpModule class methodsFor: 'setting' stamp: 'mu 1/4/2002 23:58'!
showLog
	showLog isNil ifTrue:[showLog := false].
	^showLog! !

!SoapHttpModule class methodsFor: 'setting' stamp: 'mu 1/4/2002 23:58'!
showLog: aBoolean
	showLog := aBoolean! !

!SoapHttpModule class methodsFor: 'setting' stamp: 'mu 1/4/2002 23:59'!
useTestServiceHandler
	useTestServiceHandler isNil ifTrue:[useTestServiceHandler := false].
	^useTestServiceHandler! !

!SoapHttpModule class methodsFor: 'setting' stamp: 'mu 1/4/2002 23:59'!
useTestServiceHandler: aBoolean
	useTestServiceHandler := aBoolean! !


HttpService subclass: #SoapHttpService
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-Http-Comanche'!

!SoapHttpService methodsFor: 'accessing'!
module
	module isNil ifTrue: [ module := self defaultModule].
	^module! !

!SoapHttpService methodsFor: 'accessing' stamp: 'mu 5/26/2003 23:40'!
port
	^(SoapConfigurationMap isKom6plus or: [SoapConfigurationMap isNG])
		ifTrue: [self portNumber]
		ifFalse: [self comancheServer	ifNil: [0].
			self comancheServer portNumber]! !


!SoapHttpService methodsFor: 'defaults'!
defaultModule
	^SoapHttpModule new! !


!SoapHttpService methodsFor: 'conversation' stamp: 'mu 5/26/2003 23:45'!
processHttpRequest: request
	"for Comanche NG and 6.1+"
	^self module process: request! !

!SoapHttpService methodsFor: 'conversation' stamp: 'mu 5/4/2003 18:56'!
serve: aSocket 
	^ SoapConfigurationMap isNG
		ifTrue: [HttpAdaptor
				readAndWriteTo: (SocketStream on: aSocket)
				target: [:httpRequest | self processHttpRequest: httpRequest]]
		ifFalse: [super serve: aSocket]! !

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

SoapHttpService class
	instanceVariableNames: ''!

!SoapHttpService class methodsFor: 'special' stamp: 'mu 5/29/2003 16:10'!
adaptSuperclassGuessing
	SoapConfigurationMap isKom6plus ifTrue: [self adaptSuperclassNamed: #HttpService].
	SoapConfigurationMap isNG ifTrue: [self adaptSuperclassNamed: #ComancheHttpService].
	"Otherwise, good old Comanche 5"
	self adaptSuperclassNamed: #ComancheNetService! !

!SoapHttpService class methodsFor: 'special' stamp: 'mu 5/26/2003 23:28'!
adaptSuperclassNamed: mySuperclassName 
	"I hate this - but for the Comanche 6.x BBBBIIIIGGGG API changes"
	| superCls newDefinition |
	superCls _ Smalltalk
				at: mySuperclassName asString asSymbol
				ifAbsent: [].
	superCls
		ifNil: [^ nil].
	newDefinition _ self definition copyReplaceAll: 'ProtoObject' with: mySuperclassName asString.
	[Compiler evaluate: newDefinition]
		on: Error
		do: [:ex | 
			Transcript show: 'Changing superclass failed: ' , mySuperclassName.
			^ nil]! !


SoapServerSetup subclass: #SoapHttpSetup
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-Http-Comanche'!

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

SoapHttpSetup class
	instanceVariableNames: ''!

!SoapHttpSetup class methodsFor: 'class initialization' stamp: 'mu 5/4/2003 18:49'!
initialize
	self initializeAfterLoad.
	! !


!SoapHttpSetup class methodsFor: 'actions' stamp: 'mu 5/6/2003 15:14'!
startOn: port
	self stop.
	handler := self defaultHandlerOn: port.
	^self handler start! !

!SoapHttpSetup class methodsFor: 'actions' stamp: 'mu 9/28/2003 19:32'!
stop
	"SoapHttpSetup stop"
	handler isNil
		ifFalse: [handler unregister.
			SoapConfigurationMap isKom6plus
				ifTrue: [handler waitForStop]].
	handler := nil! !


!SoapHttpSetup class methodsFor: 'defaults' stamp: 'mu 5/6/2003 15:33'!
defaultHandler
	^ self defaultHandlerOn: self defaultPort! !

!SoapHttpSetup class methodsFor: 'defaults' stamp: 'mu 5/29/2003 16:10'!
defaultHandlerOn: port 
	SoapHttpService superclass == ProtoObject
		ifTrue: [SoapHttpService adaptSuperclassGuessing].
	^ (SoapConfigurationMap isKom6plus
			or: [SoapConfigurationMap isNG])
		ifTrue: [SoapHttpService on: port named: self serviceName]
		ifFalse: [SoapHttpService named: self serviceName onPort: port]! !

!SoapHttpSetup class methodsFor: 'defaults' stamp: 'mu 12/28/2001 02:20'!
defaultPort
	defaultPort isNil ifTrue: [defaultPort := 8823].
	^defaultPort! !


!SoapHttpSetup class methodsFor: 'constants' stamp: 'mu 5/26/2003 23:43'!
serviceName
	^'SOAP'! !

!SoapHttpSetup class methodsFor: 'constants' stamp: 'mu 8/28/2002 15:30'!
transportName
	^#http! !

SoapHttpModule initialize!
SoapHttpSetup initialize!