Object subclass: #SoapSqtpHandler
	instanceVariableNames: 'status port logging service connectionHandler comListener '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-Sqtp-Server'!
!SoapSqtpHandler commentStamp: '<historical>' prior: 0!
I'm the door to other image and the door for other images to come in.
!


!SoapSqtpHandler methodsFor: 'actions-server' stamp: 'MU 10/25/2002 00:51'!
process: rawRequest
	| soapContext soapEnvelope handlerName returnEnvelope targetObjectURI |
	
	targetObjectURI := rawRequest first.
	soapEnvelope := rawRequest last.
	
	self class showLog ifTrue: [Transcript cr; show: '##' , super printString ,' Server:Request:{ ', soapEnvelope printString, '} '. ].
	
	soapContext := SoapContext new.
	soapContext targetObjectURI: targetObjectURI. "maybe method namespace"
	
	handlerName := #default.

	 returnEnvelope := soapEnvelope hasFault 
		ifTrue: [ soapEnvelope ] 
		ifFalse: [ (SoapServiceHandler named: handlerName) dispatch: soapEnvelope with: soapContext.].

	self class showLog ifTrue: [Transcript cr; show: '##' , super printString ,' Server:Return:{ ', returnEnvelope printString, '} '. ].
	
	^returnEnvelope
	
	
	
	! !

!SoapSqtpHandler methodsFor: 'actions-server' stamp: 'mu 11/20/2002 13:46'!
processSocket: aSocket 
	"process a new open socket"
	[| request result | 
	[request := SoapSqtpProtocol getObjectFrom: aSocket.
	result := self process: request.
	SoapSqtpProtocol sendReturnObject: result by: aSocket]
		on: SoapSqtpGenericError
		do: [:ex | self log: ex description]]
		ensure: [aSocket closeAndDestroy]! !


!SoapSqtpHandler methodsFor: 'logging' stamp: 'MU 8/26/2002 18:27'!
log: aString 
	self logging
		ifTrue: [Transcript cr; show: aString]! !


!SoapSqtpHandler methodsFor: 'actions' stamp: 'mu 5/4/2003 18:59'!
start
	Socket initializeNetwork.
	status := #running.
	self log: self class name, '##Running: ' , self port printString.
	self startListening.! !

!SoapSqtpHandler methodsFor: 'actions' stamp: 'mu 5/28/2003 15:45'!
startListening
	SoapConfigurationMap isKom6plus
		ifTrue: [^ self startService].
	SoapConfigurationMap isNG
		ifTrue: [^ self startComancheListener].
	self startConnectionHandler! !

!SoapSqtpHandler methodsFor: 'actions' stamp: 'mu 5/4/2003 19:03'!
stop
	status := #stoped.
	self log: self class name, '##Stoped!!'.
	self stopListening.! !

!SoapSqtpHandler methodsFor: 'actions' stamp: 'mu 9/28/2003 19:29'!
stopListening
	SoapConfigurationMap isKom6plus
		ifTrue: [^ self stopService].
	SoapConfigurationMap isNG
		ifTrue: [^ self stopComancheListener].
	^ self stopConnectionHandler! !


!SoapSqtpHandler methodsFor: 'callback' stamp: 'mu 5/4/2003 18:45'!
value: aSocket 
	"this method is invoked by ConnectioHandler or ComancheListener when a new connection is  
	established"
	[self processSocket: aSocket]
		forkAt: Processor lowIOPriority! !


!SoapSqtpHandler methodsFor: 'private' stamp: 'mu 5/28/2003 15:43'!
startComancheListener
	self stopComancheListener.
	comListener isNil
		ifFalse: [status := #running. 
				comListener := (ComancheListener on: self port handler: self)
						forkAndListenWhile: [self isRunning]]! !

!SoapSqtpHandler methodsFor: 'private' stamp: 'mu 5/4/2003 18:09'!
startConnectionHandler
	self stopConnectionHandler.
	connectionHandler isNil
		ifTrue: [connectionHandler := ConnectionHandler
						onPort: self port
						handler: self
						priority: Processor highIOPriority.
			connectionHandler start]! !

!SoapSqtpHandler methodsFor: 'private' stamp: 'mu 5/28/2003 15:55'!
startService
	self stopService.
	service isNil
		ifTrue: [service := SoapSqtpService on: self port named: 'SQTP'.
			service handler: self.
			service start]! !

!SoapSqtpHandler methodsFor: 'private' stamp: 'mu 5/28/2003 15:43'!
stopComancheListener
	"obsolete - for ComancheNG"
	comListener isNil
		ifFalse: [status := #stoped.
			(Delay forMilliseconds: 200) wait.
			comListener destroySockets.
			comListener := nil]! !

!SoapSqtpHandler methodsFor: 'private' stamp: 'MU 10/25/2002 00:52'!
stopConnectionHandler
	connectionHandler isNil
		ifFalse: [connectionHandler stop.
			connectionHandler := nil]! !

!SoapSqtpHandler methodsFor: 'private' stamp: 'mu 9/28/2003 19:30'!
stopService
	service isNil
		ifFalse: [service unregister; waitForStop].
	service := nil! !


!SoapSqtpHandler methodsFor: 'accessing' stamp: 'MU 10/25/2002 00:53'!
logging
	logging isNil ifTrue: [logging := self class showLog].
	^logging! !

!SoapSqtpHandler methodsFor: 'accessing' stamp: 'MU 10/25/2002 00:53'!
logging: aBoolean
	logging := aBoolean! !

!SoapSqtpHandler methodsFor: 'accessing' stamp: 'MU 10/25/2002 00:53'!
port
	port isNil ifTrue: [port := 4649].
	^port! !

!SoapSqtpHandler methodsFor: 'accessing' stamp: 'MU 10/25/2002 00:53'!
port: anInteger
	port := anInteger! !


!SoapSqtpHandler methodsFor: 'testing' stamp: 'MU 8/27/2002 19:08'!
isRunning
	^status == #running! !

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

SoapSqtpHandler class
	instanceVariableNames: 'default showLog '!

!SoapSqtpHandler class methodsFor: 'class initialization' stamp: 'mu 5/1/2003 19:15'!
initialize
	default := showLog := nil! !


!SoapSqtpHandler class methodsFor: 'instance creation' stamp: 'MU 10/25/2002 00:51'!
default
	"SoapSqtpServer default"
	default
		ifNil: [default := self new].
	^ default! !


!SoapSqtpHandler class methodsFor: 'setting' stamp: 'MU 8/26/2002 18:13'!
showLog
	showLog isNil ifTrue:[showLog := false].
	^showLog! !

!SoapSqtpHandler class methodsFor: 'setting' stamp: 'MU 8/26/2002 18:13'!
showLog: aBoolean
	showLog := aBoolean! !


TcpService subclass: #SoapSqtpService
	instanceVariableNames: 'handler '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-Sqtp-Server'!

!SoapSqtpService methodsFor: 'conversation' stamp: 'mu 5/28/2003 15:39'!
serve: aSocket
	handler isNil ifTrue: [self error: 'SqtpHandler is not installed'].
	^handler processSocket: aSocket 
	! !


!SoapSqtpService methodsFor: 'accessing' stamp: 'mu 5/28/2003 15:37'!
handler
	^handler! !

!SoapSqtpService methodsFor: 'accessing' stamp: 'mu 5/28/2003 15:37'!
handler: aSoapSqtphandler
	handler := aSoapSqtphandler! !


SoapServerSetup subclass: #SoapSqtpSetup
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-Sqtp-Server'!

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

SoapSqtpSetup class
	instanceVariableNames: ''!

!SoapSqtpSetup class methodsFor: 'class initialization' stamp: 'MU 10/5/2002 02:31'!
initialize
	self initializeAfterLoad! !


!SoapSqtpSetup class methodsFor: 'utility' stamp: 'MU 8/28/2002 12:05'!
logging: aBoolean
	"SoapSqtpSetup logging: true"
	self handler logging: aBoolean! !


!SoapSqtpSetup class methodsFor: 'accessing' stamp: 'MU 8/26/2002 17:06'!
defaultPort: anInteger
	self stop.
	defaultPort := anInteger.
	self start! !


!SoapSqtpSetup class methodsFor: 'defaults' stamp: 'MU 8/28/2002 12:03'!
defaultHandler
	^SoapSqtpHandler default port: self defaultPort! !

!SoapSqtpSetup class methodsFor: 'defaults' stamp: 'MU 8/26/2002 18:46'!
defaultPort
	defaultPort isNil ifTrue: [defaultPort := 4649].
	^defaultPort! !


!SoapSqtpSetup class methodsFor: 'constants' stamp: 'mu 8/28/2002 16:18'!
transportName
	^#sqtp! !

SoapSqtpHandler initialize!
SoapSqtpSetup initialize!