Object subclass: #SoPortableTestUtil
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-TestCases'!

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

SoPortableTestUtil class
	instanceVariableNames: ''!

!SoPortableTestUtil class methodsFor: 'actions' stamp: 'mu 9/10/2001 01:07'!
createHttpRequest
	
	| req |
	req := HttpRequest new.
	req header: (HttpParser parseHttpHeader: self httpRequestHeaderString).
	req initStatusString: 'POST /SomeTarget HTTP/1.1'.
	^req! !

!SoPortableTestUtil class methodsFor: 'actions' stamp: 'mu 9/10/2001 00:42'!
httpRequestFrom: aString
	"ToDo: Support other Smalltalks"
	"##Squeak Comanche specific##"

	^HttpRequest new header: (HttpParser parseHttpHeader: aString)! !


!SoPortableTestUtil class methodsFor: 'private' stamp: 'mu 9/10/2001 01:00'!
httpRequestHeaderString
	| crlfString |
	crlfString := String with: Character cr with: Character lf.
	
	^ 'POST /StockQuote HTTP/1.1', crlfString, 
       'Host: www.stockquoteserver.com', crlfString, 
       'Content-Type: text/xml; charset="utf-8"', crlfString, 
       'Content-Length: nnnn', crlfString, 
       'SOAPAction: "Some-URI"'! !


TestCase subclass: #SoSoapFaultDetailBuilderTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-TestCases'!

!SoSoapFaultDetailBuilderTestCase methodsFor: 'for workspace' stamp: 'mu 11/3/2001 20:14'!
doItInWorkspace
	"SoSoapFaultDetailBuilderTestCase new doItInWorkspace"
	| soapFaultDetail res1 res2 res3 details res4 res5 res6 results |
	soapFaultDetail := [1 / 0]
				on: Error
				do: [:ex | 
					| build de | 
					build := SoapFaultDetailBuilder new.
					de := build buildSoapFaultDetailOn: SoapFault server from: ex.
					de].
	res1 := soapFaultDetail parent name= 'SOAP-ENV:Fault'.
	res2 := soapFaultDetail parent faultstring =  'ZeroDivide'.
	res3 := soapFaultDetail name = 'detail'.
	details := soapFaultDetail subElements first.
	res4 := details shortName = 'details'.
	res5 := (details declaredNamespaceURIFor: SoapFaultDetailBuilder defaultPrefix)
				= SoapFaultDetailBuilder defaultNamespace.
	
	res6 := (details findChildNamed: 'ErrorClass') value =  'ZeroDivide'.
	
	results := OrderedCollection new.
	results add: res1.
	results add: res2.
	results add: res3.
	results add: res4.
	results add: res5.
	results add: res6.
	results inspect
	




! !


!SoSoapFaultDetailBuilderTestCase methodsFor: 'testing' stamp: 'mu 11/3/2001 20:11'!
testBuildSoapFaultDetailWithZeroDivide
	"###COULD NOT RUN - BECAUSE OF SUNIT ERROR###"
	"DO it in workspace instead"
	"| soapFaultDetail  details |
	soapFaultDetail := [1 / 0]
				on: ZeroDivide
				do: [:ex | 
					| build de | 
					build := SoapFaultDetailBuilder new.
					de := build buildSoapFaultDetailOn: SoapFault server from: ex.
					de].
	self should: [soapFaultDetail parent name = 'SOAP-ENV:Fault'].
	self should: [soapFaultDetail parent faultstring =  'ZeroDivide'].
	self should: [soapFaultDetail name = 'detail'].
	details := soapFaultDetail subElements first.
	self should: [details shortName = 'details'].
	self should: [(details declaredNamespaceURIFor: SoapFaultDetailBuilder defaultPrefix)
				= SoapFaultDetailBuilder defaultNamespace].
	
	self should:[ (details findChildNamed: 'ErrorClass') value =  'ZeroDivide']."
	! !


TestCase subclass: #SoXmlAttributesHolderTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-TestCases'!

!SoXmlAttributesHolderTestCase methodsFor: 'testing' stamp: 'mu 8/12/2001 19:30'!
testAsDictionary
	| attribsHolder dict |
	attribsHolder := SoXmlAttributesHolder new.
	attribsHolder putAttribute: #('key1' 'val1').
	attribsHolder putAttribute: #('key2' 'val2').
	dict := attribsHolder asDictionary.
	self should: [ ( dict at: 'key1' ) = 'val1'].
	self should: [ ( dict at: 'key2' ) = 'val2'].
	
	! !

!SoXmlAttributesHolderTestCase methodsFor: 'testing' stamp: 'mu 9/18/2001 19:20'!
testDeclareNamespaceURIs
	| attribsHolder |
	attribsHolder := SoXmlAttributesHolder new.
	attribsHolder declareNamespace: 'Foo1' uri: 'http://www.bar.org'.
	attribsHolder declareNamespace: 'Foo2' uri: 'http://www.baz.org'.
	
	self should: [(attribsHolder declaredNamespaceURIFor: 'Foo1') = 'http://www.bar.org'].
	self should: [(attribsHolder declaredNamespaceURIFor: 'Foo2') = 'http://www.baz.org'].
	! !

!SoXmlAttributesHolderTestCase methodsFor: 'testing' stamp: 'mu 4/15/2001 01:20'!
testDeclareNamespaces
	| attribsHolder |
	attribsHolder := SoXmlAttributesHolder new.
	attribsHolder declareNamespace: 'Foo1' uri: 'http://www.bar.org'.
	attribsHolder declareNamespace: 'Foo2' uri: 'http://www.baz.org'.
	self should: [attribsHolder declaredNamespacePrefixes asArray = #('Foo1' 'Foo2')].
	! !

!SoXmlAttributesHolderTestCase methodsFor: 'testing' stamp: 'mu 4/15/2001 01:22'!
testDeclareNamespacesAndPutAttributes
	| attribsHolder ansStr |
	attribsHolder := SoXmlAttributesHolder new.
	attribsHolder declareNamespace: 'Foo1' uri: 'http://www.bar.org'.
	attribsHolder putAttribute: #('key1' 'val1').
	ansStr := ' xmlns:Foo1="http://www.bar.org" key1="val1"'.
	self should: [ansStr = attribsHolder printString]
	
	! !

!SoXmlAttributesHolderTestCase methodsFor: 'testing' stamp: 'mu 4/15/2001 01:10'!
testPutAttributes
	| attribsHolder |
	attribsHolder := SoXmlAttributesHolder new.
	attribsHolder putAttribute: #('key1' 'val1').
	self should: ['val1' = (attribsHolder getAttributeNamed: 'key1')].
	attribsHolder putAttribute: #('key1' 'val2').
	self shouldnt: ['val1' = (attribsHolder getAttributeNamed: 'key1')].
	self should: ['val2' = (attribsHolder getAttributeNamed: 'key1')].
	
	! !


TestCase subclass: #SoXmlUtilTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-TestCases'!

!SoXmlUtilTestCase methodsFor: 'testing' stamp: 'mu 4/15/2001 00:52'!
testAttribDict
	| elem dic1 dic2 |
	elem :=self simpleXmlElement.
	dic1 := SoXmlUtil attribDictFrom: elem.
	dic2 := Dictionary new.
	dic2 at: 'a' put: '1'.
	dic2 at: 'b' put: '2'.
	self should:[dic1 = dic2]
	! !

!SoXmlUtilTestCase methodsFor: 'testing' stamp: 'mu 4/15/2001 00:52'!
testComplexStringWrite
	| str1 str2 str3 |
	str1 := self compString.
	str2 := SoXmlUtil asXmlText: str1.
	str3 := self normalString, '&lt;&gt;&apos;&quot;&amp;'.
	self shouldnt: [str1 = str2].
	self should:[str2 = str3]! !

!SoXmlUtilTestCase methodsFor: 'testing' stamp: 'mu 4/15/2001 00:52'!
testConvStringWrite
	| str1 str2 str3 |
	str1 := self convString.
	str2 := SoXmlUtil asXmlText: str1.
	str3 := '&lt;&gt;&apos;&quot;&amp;'.
	self shouldnt: [str1 = str2].
	self should:[str2 = str3]
	! !

!SoXmlUtilTestCase methodsFor: 'testing' stamp: 'mu 9/24/2001 01:39'!
testElementName
	| elem nm |
	elem :=self simpleXmlElement.
	nm := SoXmlUtil elementNameFrom: elem.
	self should:[nm = 'Foo'].
	
	! !

!SoXmlUtilTestCase methodsFor: 'testing' stamp: 'mu 9/24/2001 01:39'!
testElementShortName
	
	| elem2 nm2 |
	elem2 := self namespacedSimpleXmlElement.
	nm2 := SoXmlUtil elementShortNameFrom: elem2.
	self should:[nm2 = 'Bar'].
	! !

!SoXmlUtilTestCase methodsFor: 'testing' stamp: 'mu 4/15/2001 00:52'!
testElementsWithoutTexts
	
	| elem1 elems1 elem2 elems2 |
	elem1 :=self simpleXmlElement.
	elems1 := SoXmlUtil elementsWithoutTextsFrom: elem1.
	elem2 :=self simpleXmlElementWithText.
	elems2 := SoXmlUtil elementsWithoutTextsFrom: elem2.
	self should: [elems1 size = elems2 size].
	self should: [elems1 printString  = elems2 printString]
	! !

!SoXmlUtilTestCase methodsFor: 'testing' stamp: 'mu 4/15/2001 00:52'!
testNormalStringWrite
	| str1 str2 |
	str1 := self normalString.
	str2 := SoXmlUtil asXmlText: str1.
	self should: [str1 = str2]
	! !


!SoXmlUtilTestCase methodsFor: 'fixtures' stamp: 'mu 3/27/2001 01:28'!
compString
	^self normalString, self convString! !

!SoXmlUtilTestCase methodsFor: 'fixtures' stamp: 'mu 3/27/2001 01:20'!
convString
	^'<>''"&'! !

!SoXmlUtilTestCase methodsFor: 'fixtures' stamp: 'mu 9/24/2001 01:33'!
nameapacedSimpleXmlString
	^'<m:Bar a="1" b="2" xmlns:m="http://soapinterop.org/">
		<bar>cont</bar>
	</m:Bar>'
	! !

!SoXmlUtilTestCase methodsFor: 'fixtures' stamp: 'mu 9/24/2001 01:34'!
namespacedSimpleXmlElement
	^(SoXmlUtil parseXml: self nameapacedSimpleXmlString)! !

!SoXmlUtilTestCase methodsFor: 'fixtures' stamp: 'mu 4/8/2001 23:58'!
normalString
	^'SoapOpera is a Squeak SOAP implementaion written by Masashi Umezawa'! !

!SoXmlUtilTestCase methodsFor: 'fixtures' stamp: 'mu 4/15/2001 00:52'!
simpleXmlElement
	^(SoXmlUtil parseXml: self simpleXmlString)! !

!SoXmlUtilTestCase methodsFor: 'fixtures' stamp: 'mu 4/15/2001 00:52'!
simpleXmlElementWithText
	^(SoXmlUtil parseXml: self simpleXmlStringWithText)! !

!SoXmlUtilTestCase methodsFor: 'fixtures' stamp: 'mu 4/11/2001 00:59'!
simpleXmlString
	^'<Foo a="1" b="2">
		<bar>cont</bar>
	</Foo>'
	! !

!SoXmlUtilTestCase methodsFor: 'fixtures' stamp: 'mu 4/11/2001 00:59'!
simpleXmlStringWithText
	^'<Foo a="1" b="2">
		some text...
		<bar>cont</bar>
	</Foo>'
	! !


TestCase subclass: #SoXmlWrapElementTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-TestCases'!

!SoXmlWrapElementTestCase methodsFor: 'testing' stamp: 'mu 1/14/2002 02:53'!
testElemPrint1
	| fixString wStr xmlElem  |
	fixString := '<Foo>bar</Foo>
'.
	wStr := WriteStream on: (String new: 16).
	xmlElem := SoXmlWrapElement new.
	xmlElem name: 'Foo'.
	xmlElem value: 'bar'.
	xmlElem printXmlOn: wStr.
	self should: [wStr contents = fixString]! !

!SoXmlWrapElementTestCase methodsFor: 'testing' stamp: 'mu 1/14/2002 02:54'!
testElemPrint2
	| fixString wStr xmlElem  child |
	fixString :=  '<SMIX>
 <interchangeUnit>
  <classDefinition className="Customer">
   <instVarNames>name address tel</instVarNames>
  </classDefinition>
 </interchangeUnit>
</SMIX>
'.
	wStr := WriteStream on: (String new: 16).
	xmlElem := SoXmlWrapElement new.
	xmlElem name: 'SMIX'.
	child := xmlElem createChildNamed: 'interchangeUnit'.
	child := child createChildNamed: 'classDefinition'.
	child putAttribute: #(className Customer).
	child := child createChildNamed: 'instVarNames'.
	child value: 'name address tel'.
	xmlElem printXmlOn: wStr.
	
	self should:[wStr contents = fixString].! !


TestCase subclass: #SoapActionTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-TestCases'!

!SoapActionTestCase methodsFor: 'testing' stamp: 'mu 1/27/2002 02:29'!
testIntent
	
	| act |
	act := SoapAction intent: 'urn:targetObjectURI:fooBar'.
	self should: [act printString =  ('SOAPAction: ', '"urn:targetObjectURI:fooBar"',(String with: Character cr with: Character lf))].! !

!SoapActionTestCase methodsFor: 'testing' stamp: 'mu 1/27/2002 02:29'!
testIntentByRequestURI
	
	| act |
	act := SoapAction intentByRequestURI.
	self should: [act printString =  ('SOAPAction: ', '""',(String with: Character cr with: Character lf))].! !

!SoapActionTestCase methodsFor: 'testing' stamp: 'mu 1/27/2002 02:28'!
testNoIntent
	
	| act |
	act := SoapAction noIntent.
	self should: [act printString = ('SOAPAction: ', (String with: Character cr with: Character lf)) ].! !


TestCase subclass: #SoapBodyTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-TestCases'!

!SoapBodyTestCase methodsFor: 'testing' stamp: 'mu 5/6/2001 01:47'!
testAddBodyEntries
	| body ent1 ent2 |
	body := SoapBody new.
	ent1 := SoapWrapElement named: 'request1' withPrefix: 'm1'.
	ent1 declareNamespace: 'm1' uri: 'urn:request:1'.
	body addBodyEntry: ent1.
	ent2 := SoapWrapElement named: 'request1' withPrefix: 'm2'.
	ent2 declareNamespace: 'm2' uri: 'urn:request:2'.
	body addBodyEntry: ent2.
	
	self should:[ent1 parent =  body].
	self should:[ent2 parent =  body].
	
	self should:[(body bodyEntries at: 1 ) = ent1].
	self should:[(body bodyEntries at: 2 ) = ent2].
	
	
	! !

!SoapBodyTestCase methodsFor: 'testing' stamp: 'mu 4/22/2001 02:51'!
testIsMustUnderstandEnabled
	| body |
	body := SoapBody new.
	self should:[body isMustUnderstandEnabled].! !

!SoapBodyTestCase methodsFor: 'testing' stamp: 'mu 12/31/2001 01:50'!
testOverrideEncodingStyle
	| env body ent1 |
	env := SoapEnvelope new.
	env declareSoapEncEncoding.
	self should: [ (env getAttributeNamed: (SoapConstants soapEnvPrefix,':', SoapConstants encodingStyle) ) 
			= SoapConstants soapEncURI].
	self should: [env encodingStyleURIs = (Array with: (SoapConstants soapEncURI))].
	
	body := env addBody.
	body declareNamespace: 'b' uri: 'urn:body:1'.
	body declareEncodingIn: 'b' uri: 'urn:encoding:1'.
	self shouldnt: [body encodingStyleURIs = (Array with: (SoapConstants soapEncURI))].
	self should:[body encodingStyleURIs = (Array with: ('urn:encoding:1'))].
	
	ent1 := SoapWrapElement named: 'request1' withPrefix: 'm1'.
	ent1 declareNamespace: 'm1' uri: 'urn:request:1'.
	body declareEncodingIn: 'm1' uri: 'urn:encoding:2'.
	body addBodyEntry: ent1.
	self should:[ent1 encodingStyleURIs = (Array with: ('urn:encoding:2'))].
	
	
	
	
	
	
! !


TestCase subclass: #SoapCallTestCase
	instanceVariableNames: 'originalTransports '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-TestCases'!

!SoapCallTestCase methodsFor: 'testing' stamp: 'mu 5/2/2003 18:47'!
testAnyArrayHttpCall
	| handlerName call resp |
	SoapServerSetup startOnly: #(http). 
	
	handlerName := SoapServiceHandler useTestServiceHandler ifTrue: [#test] ifFalse: [#default].
	(SoapServiceHandler named: handlerName ) add: self simpleAddService.
	call := (SoapCallEntry local: (SoapServerSetup defaultPortAt: #http)) newCall.
	call transport: #http.
	call methodName: 'add'.
	call addParameter: (SoapVariable name: #newElem value: #(1.0 'two' 3)).
	
	resp := call invoke.
	
	self shouldnt:[resp isFault].
	self should:[resp returnValue = #(1.0 'two' 3)].
	
	(SoapServiceHandler named: handlerName) remove: self simpleAddService.
	
	
	
	
	! !

!SoapCallTestCase methodsFor: 'testing' stamp: 'mu 5/2/2003 16:59'!
testCannotConnectHttpCall
	| notUsedPort call resp |
	notUsedPort := 9876.
	call := (SoapCallEntry tcpHost: 'localhost' port: notUsedPort) newCall.
	call transport: #http.
	call methodName: 'helloWorld'.
	
	resp := call invoke.
	
	self should:[resp isFault].
	self should:[resp returnValue = nil].
	self should: [resp raiseException] raise: SoapCannotConnectToServer
	
	
	
	
	
	
	! !

!SoapCallTestCase methodsFor: 'testing' stamp: 'mu 5/2/2003 16:59'!
testCannotConnectResolveCall
	| call resp |

	call := (SoapCallEntry tcpHost: 'foobarbazboo' port: 8823) newCall.
	call transport: #http.
	call methodName: 'helloWorld'.
	
	resp := call invoke.
	
	self should:[resp isFault].
	self should:[resp returnValue = nil].
	self should: [resp raiseException] raise: SoapCannotResolveServer
	
	
	
	
	
	
	! !

!SoapCallTestCase methodsFor: 'testing' stamp: 'MU 4/18/2003 16:14'!
testCannotResolveHttpCall
	| notUsedPort call resp |
	notUsedPort := 9876.
	call := (SoapCallEntry tcpHost: 'localhost' port: notUsedPort) newCall.
	call transport: #http.
	call methodName: 'helloWorld'.
	
	resp := call invoke.
	
	self should:[resp isFault].
	self should:[resp returnValue = nil].
	self should: [resp raiseException] raise: SoapCannotConnectToServer
	
	
	
	
	
	
	! !

!SoapCallTestCase methodsFor: 'testing' stamp: 'mu 2/1/2002 00:04'!
testComplexSqEncoding
	| call pa1 pa2 env methodElem arg1 arg2 |
	call := SoapCall new.
	call transport: #localRpc.
	call targetObjectURI: 'urn:auauObject'.
	call encoding: #soapSqEncoding.
	call methodName: 'auau'.
	pa1 := (SoapVariable name: #arg1 value: 1).
	pa2 := (SoapVariable name: #arg2 value: #two) encoding: #soapSqEncoding.
	call addParameter: pa1.
	call addParameter: pa2.
	env := call buildEnvelope.
	
	self should: [env name = 'env:Envelope'].
	self should: [env body name = 'env:Body'].
	self should: [(env getAttributeNamed: 'env:encodingStyle') = SoapConstants soapSqEncURI]. 
	methodElem := env body bodyEntries first.
	self should: [ methodElem name = 'm:auau'].
	arg1 := methodElem children at: 1.
	self should:[ arg1 name = 'arg1']. 
	self should:[ (arg1 getAttributeNamed: 'xsi:type') = 'xsd:integer']. 
	self should:[ (arg1 encodingStyleURIs first) = SoapConstants soapSqEncURI]. 
	self should:[ arg1 value = '1']. 
	arg2 := methodElem children at: 2.
	self should:[ arg2 name = 'arg2']. 
	self should:[ (arg2 getAttributeNamed: 'xsi:type') =  'Squeak-ENC:ReferenceStream']. 
	
	
	
	
	! !

!SoapCallTestCase methodsFor: 'testing' stamp: 'mu 5/2/2003 18:47'!
testComplexSqHttpCall
	| handlerName call resp |
	SoapServerSetup startOnly: #(http).
	
	handlerName := SoapServiceHandler useTestServiceHandler ifTrue: [#test] ifFalse: [#default].
	(SoapServiceHandler named: handlerName ) add: self simpleAddService.
	call := (SoapCallEntry local: (SoapServerSetup defaultPortAt: #http)) newCall.
	call transport: #http.
	call encoding: #soapSqEncoding.
	call methodName: 'add'.
	call addParameter: (SoapVariable name: #newElem).
	
	resp := call invokeWithValue: #symbol.
	self shouldnt:[resp isFault].
	self should:[resp returnValue = #symbol].
	
	resp := call invokeWithValue: Date today.
	self shouldnt:[resp isFault].
	self should:[resp returnValue = Date today].
	
	resp := call invokeWithValue: (OrderedCollection with: #(1 2 #('three' 3) with: Date today)).
	self shouldnt:[resp isFault].
	self should:[resp returnValue = (OrderedCollection with: #(1 2 #('three' 3) with: Date today))].
	
	(SoapServiceHandler named: handlerName) remove: self simpleAddService.
	
	
	
	
	! !

!SoapCallTestCase methodsFor: 'testing' stamp: 'mu 6/28/2001 01:16'!
testDefaultEncodingCreation
	| call |
	call := SoapCall new.
	call targetObjectURI: 'urn:target:1'.
	call encoding: #soapEncoding.
	self should: [call encoder class = SoapEncoder].
	! !

!SoapCallTestCase methodsFor: 'testing' stamp: 'mu 5/2/2003 18:47'!
testIntegerArrayHttpCall
	| handlerName call resp |
	SoapServerSetup startOnly: #(http).
	
	handlerName := SoapServiceHandler useTestServiceHandler ifTrue: [#test] ifFalse: [#default].
	(SoapServiceHandler named: handlerName ) add: self simpleAddService.
	call := (SoapCallEntry local: (SoapServerSetup defaultPortAt: #http)) newCall.
	call transport: #http.
	call methodName: 'add'.
	call addParameter: (SoapVariable name: #newElem value: #(1 2 3)).
	
	resp := call invoke.
	
	self shouldnt:[resp isFault].
	self should:[resp returnValue = #(1 2 3)].
	
	(SoapServiceHandler named: handlerName) remove: self simpleAddService.
	
	
	
	
	! !

!SoapCallTestCase methodsFor: 'testing' stamp: 'MU 3/25/2002 00:47'!
testSimpleEnvelopeCreatein
	| call env methodElem arg1 arg2 |
	call := SoapCall new.
	call methodName: 'auau'.
	call addParameter: (SoapVariable name: #arg1 value: 1).
	call addParameter: (SoapVariable name: #arg2 value: 'two').
	env := call buildEnvelope.
	
	self should: [env name = 'env:Envelope'].
	self should: [env body name = 'env:Body'].
	methodElem := env body bodyEntries first.
	self should: [ methodElem name = 'm:auau'].
	arg1 := methodElem children at: 1.
	self should:[ arg1 name = 'arg1']. 
	self should:[ (arg1 xsiType) = 'xsd:integer']. 
	self should:[ arg1 value = '1']. 
	arg2 := methodElem children at: 2.
	self should:[ arg2 name = 'arg2']. 
	self should:[ (arg2 xsiType) = 'xsd:string']. 
	self should:[ arg2 value = 'two']. 
	
	! !

!SoapCallTestCase methodsFor: 'testing' stamp: 'mu 5/2/2003 18:47'!
testSimpleHttpCall
	| handlerName call resp |
	SoapServerSetup startOnly: #(http).
	
	handlerName := SoapServiceHandler useTestServiceHandler ifTrue: [#test] ifFalse: [#default].
	(SoapServiceHandler named: handlerName ) add: self simpleAddService.
	call := (SoapCallEntry local: (SoapServerSetup defaultPortAt: #http)) newCall.
	call transport: #http.
	call methodName: 'add'.
	call addParameter: (SoapVariable name: #newElem value: 1).
	
	resp := call invoke.
	
	self shouldnt:[resp isFault].
	self should:[resp returnValue = 1].
	
	(SoapServiceHandler named: handlerName) remove: self simpleAddService.
	
	
	
	
	! !

!SoapCallTestCase methodsFor: 'testing' stamp: 'mu 5/2/2003 18:47'!
testSimpleHttpCallWithError
	| handlerName call resp |
	SoapServerSetup startOnly: #(http).
	
	handlerName := SoapServiceHandler useTestServiceHandler ifTrue: [#test] ifFalse: [#default].
	(SoapServiceHandler named: handlerName ) add: self simpleAddService.
	call := (SoapCallEntry local: (SoapServerSetup defaultPortAt: #http)) newCall.
	call methodName: 'add'.
	call addParameter: (SoapVariable name: #badArg1 value: 1).

	resp := call invoke.
	self should:[resp isFault].
	self should:[resp returnValue = nil].
	self should:[resp raiseException] raise: SoapInvalidParamName.
	
	
	(SoapServiceHandler named: handlerName) remove: self simpleAddService.
	
	
	
	
	! !

!SoapCallTestCase methodsFor: 'testing' stamp: 'mu 11/23/2001 23:45'!
testSimpleLocalCall
	| call resp |
	SoapServiceHandler default  add: self simpleAddService.
	call := SoapCallEntry local newCall.
	call transport: #localRpc.
	call methodName: 'add'.
	call addParameter: (SoapVariable name: #newElem value: 1).
	
	resp := call invoke.
	
	self shouldnt:[resp isFault].
	self should:[resp returnValue = 1].
	
	SoapServiceHandler default remove: self simpleAddService.
	
	
	
	! !

!SoapCallTestCase methodsFor: 'testing' stamp: 'mu 11/24/2001 01:52'!
testSimpleLocalCallWithError
	| call resp |
	SoapServiceHandler default  add: self simpleAddService.
	call := SoapCallEntry local newCall.
	call transport: #localRpc.
	call methodName: 'add'.
	call addParameter: (SoapVariable name: #badArg1 value: 1).
	resp := call invoke.
	self should:[resp isFault].
	self should:[resp returnValue = nil].
	self should:[resp raiseException] raise: SoapInvalidParamName.
		
	SoapServiceHandler default remove: self simpleAddService.
	
	
	
	! !

!SoapCallTestCase methodsFor: 'testing' stamp: 'mu 12/28/2001 01:35'!
testSimpleSqCall

	| call resp |
	SoapServiceHandler default  add: self simpleAddService.
	call := SoapCallEntry local newCall.
	call transport: #localRpc.
	call encoding: #soapSqEncoding.
	call methodName: 'add'.
	call addParameter: (SoapVariable name: #newElem value: 1).
	
	resp := call invoke.
	
	self shouldnt:[resp isFault].
	self should:[resp returnValue = 1].
	
	SoapServiceHandler default remove: self simpleAddService.
	
	
	
	! !

!SoapCallTestCase methodsFor: 'testing' stamp: 'mu 5/2/2003 18:47'!
testSimpleSqHttpCall
	| handlerName call resp |
	SoapServerSetup startOnly: #(http).
	
	handlerName := SoapServiceHandler useTestServiceHandler ifTrue: [#test] ifFalse: [#default].
	(SoapServiceHandler named: handlerName ) add: self simpleAddService.
	call := (SoapCallEntry local: (SoapServerSetup defaultPortAt: #http)) newCall.
	call transport: #http.
	call encoding: #soapSqEncoding.
	call methodName: 'add'.
	call addParameter: (SoapVariable name: #newElem value: 1).
	
	resp := call invoke.
	
	self shouldnt:[resp isFault].
	self should:[resp returnValue = 1].
	
	(SoapServiceHandler named: handlerName) remove: self simpleAddService.
	
	
	
	
	! !

!SoapCallTestCase methodsFor: 'testing' stamp: 'mu 6/28/2001 01:16'!
testSqEncodingCreation
	| call |
	call := SoapCall new.
	call targetObjectURI: 'urn:target:1'.
	call encoding: #soapSqEncoding.
	self should: [call encoder class = SoapSqEncoder].
	! !


!SoapCallTestCase methodsFor: 'fixtures' stamp: 'mu 11/10/2001 20:03'!
simpleAddService
	| ord serv |
	ord := OrderedCollection new.
	serv := SoapService implementor: ord selector: #add:.
	serv signature: (SoapServiceSignature name: 'add' paramNames: #(newElem)).
	^serv! !


!SoapCallTestCase methodsFor: 'running' stamp: 'MU 4/18/2003 17:20'!
setUp
	originalTransports := SoapServerSetup runningTransportNames.
	! !

!SoapCallTestCase methodsFor: 'running' stamp: 'MU 4/18/2003 17:20'!
tearDown
	
	SoapServerSetup startOnly: originalTransports! !


TestCase subclass: #SoapConnectorTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-TestCases'!

!SoapConnectorTestCase methodsFor: 'testing' stamp: 'mu 6/6/2001 00:49'!
testCreateConnector
	| con |
	con := SoapConnectorFactory createFrom: #http.
	self should: [con class = SoapHttpConnector].
	
	self should: [SoapConnectorFactory createFrom: #auau] raise: SoapNoSuchConnector.! !


TestCase subclass: #SoapDecoderTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-TestCases'!

!SoapDecoderTestCase methodsFor: 'testing' stamp: 'MU 3/25/2002 00:50'!
testDecodeAnyArray
	
	| dec ret |
	dec := SoapDecoder new.
	ret := dec decodeXmlElement: (SoapVariable name: 'anyArr1' value: #(1 '2' 3.0)) asXmlElement.
	self should: [ ret = #(1 '2' 3.0)].
	! !

!SoapDecoderTestCase methodsFor: 'testing' stamp: 'mu 9/28/2003 19:42'!
testDecodeArrayOfArray
	| dec arrayElem ret |
	dec := SoapDecoder new.
	arrayElem := SoapWrapElement fromXml: self arrayOfArrayXML.
	ret := dec decodeXmlElement: arrayElem.
	self should: [(ret at: #Array)
				isKindOf: Array].
	self should: [((ret at: #Array)
				at: 1)
				= #()].
	self should: [((ret at: #Array)
				at: 2)
				= #(17974494715439249409 'aV34fTn/QoILMlilPla2Pw==' '20030913T14:26:28 +200')]! !

!SoapDecoderTestCase methodsFor: 'testing' stamp: 'MU 5/29/2002 00:42'!
testDecodeArrayWithEmptyString
	| dec arrayElem ret |
	dec := SoapDecoder new.
	arrayElem := SoapWrapElement fromXml: self arrayWithEmptyStringXML.
	ret := dec decodeXmlElement: arrayElem.
	self should: [(ret at: #anArray)
				isKindOf: Array].
	self should: [((ret at: #anArray)
				at: 2)
				= '']! !

!SoapDecoderTestCase methodsFor: 'testing' stamp: 'mu 2/6/2002 02:00'!
testDecodeBase64Binary
	
	| dec ret bytes |
	dec := SoapDecoder new.
	bytes := ByteArray with: 1 with: 2 with: 3 with: 4.
	ret := dec decodeXmlElement: (SoapVariable name: 'binbin' value: bytes type: #ByteArray) asXmlElement.
	self should: [ ret = bytes].
	! !

!SoapDecoderTestCase methodsFor: 'testing' stamp: 'mu 9/2/2001 02:28'!
testDecodeBoolean
	
	| dec ret |
	dec := SoapDecoder new.
	ret := dec decodeXmlElement: (SoapVariable name: 'arg1' value: 'true' type: #Boolean) asXmlElement.
	self should: [ ret = true].
	! !

!SoapDecoderTestCase methodsFor: 'testing' stamp: 'MU 5/29/2002 01:18'!
testDecodeComplexData
	
	| dec complexElem ret resultElements resultElement directoryCategory |
	dec := SoapDecoder new.
	complexElem := SoapWrapElement fromXml: self complexDataXML.
	ret := dec decodeXmlElement: complexElem.
	self should: [ ret isKindOf: Dictionary].
	self should: [ (ret at: #startIndex) = 1].
	self should: [ (ret at: #searchTime) = 0.194871].
	self should: [ (ret at: #searchQuery) = 'squeak'].
	resultElements := ret at: #resultElements.
	self should: [resultElements isKindOf: Array].
	self should: [resultElements size = 1].
	resultElement := resultElements first.
	self should: [resultElement isKindOf: Dictionary].
	self should: [(resultElement at: #URL) = 'http://www.squeak.org'].
	self should: [(resultElement at: #title) = 'Squeak home page'].
	directoryCategory := resultElement at: #directoryCategory.
	self should: [directoryCategory isKindOf: Dictionary].
	self should: [(directoryCategory at: #fullViewableName) = ''].
	
		




	
	! !

!SoapDecoderTestCase methodsFor: 'testing' stamp: 'MU 5/29/2002 00:52'!
testDecodeEmptyString
	
	| dec ret |
	dec := SoapDecoder new.
	ret := dec decodeXmlElement: (SoapVariable name: 'arg1' value: '' type: #String) asXmlElement.
	self should: [ ret = ''].
	! !

!SoapDecoderTestCase methodsFor: 'testing' stamp: 'MU 3/25/2002 00:52'!
testDecodeFloatArray
	
	| dec ret |
	dec := SoapDecoder new.
	ret := dec decodeXmlElement: (SoapVariable name: 'floatArr1' value: #(1.1 2.2 3.3)) asXmlElement.
	self should: [ ret = #(1.1 2.2 3.3)].
	! !

!SoapDecoderTestCase methodsFor: 'testing' stamp: 'mu 9/2/2001 02:17'!
testDecodeInteger
	
	| dec ret |
	dec := SoapDecoder new.
	ret := dec decodeXmlElement: (SoapVariable name: 'arg1' value: '1234567' type: #Integer) asXmlElement.
	self should: [ ret = 1234567].
	! !

!SoapDecoderTestCase methodsFor: 'testing' stamp: 'MU 3/24/2002 01:55'!
testDecodeIntegerArray
	
	| dec ret |
	dec := SoapDecoder new.
	ret := dec decodeXmlElement: (SoapVariable name: 'intArr1' value: #(1 2 3) type: #Array) asXmlElement.
	self should: [ ret = #(1 2 3)].
	! !

!SoapDecoderTestCase methodsFor: 'testing' stamp: 'mu 9/2/2001 02:15'!
testDecodeString
	
	| dec ret |
	dec := SoapDecoder new.
	ret := dec decodeXmlElement: (SoapVariable name: 'arg1' value: 'Smalltalk' type: #String) asXmlElement.
	self should: [ ret = 'Smalltalk'].
	! !

!SoapDecoderTestCase methodsFor: 'testing' stamp: 'MU 3/25/2002 00:45'!
testDecodeStringArray
	
	| dec ret |
	dec := SoapDecoder new.
	ret := dec decodeXmlElement: (SoapVariable name: 'stringArr1' value: #('a' 'b' '<c>') type: #Array) asXmlElement.
	self should: [ ret = #('a' 'b' '<c>')].
	! !


!SoapDecoderTestCase methodsFor: 'fixtures' stamp: 'mu 9/28/2003 19:41'!
arrayOfArrayXML
	^ '<m:reverseArray
xmlns:m="http://www.mars.dti.ne.jp/~umejava/smalltalk/soapOpera/rpc/"
SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/"
xmlns:SOAP-ENC="http://schemas.xmlsoap.org/soap/encoding/"
xmlns:xsd="http://www.w3.org/2001/XMLSchema"
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/">
<SOAP-ENC:Array xsi:type="SOAP-ENC:Array" 
SOAP-ENC:arrayType="SOAP-ENC:Array[2]">
 <item xsi:type="SOAP-ENC:Array" SOAP-ENC:arrayType="xsd:anyType[0]">
 </item>
  <item xsi:type="SOAP-ENC:Array" SOAP-ENC:arrayType="xsd:anyType[3]">
   <item xsi:type="xsd:int">17974494715439249409</item>
   <item xsi:type="xsd:string">aV34fTn/QoILMlilPla2Pw==</item>
   <item xsi:type="xsd:string">20030913T14:26:28 &#43;200</item>
  </item>
</SOAP-ENC:Array>
</m:reverseArray>
'! !

!SoapDecoderTestCase methodsFor: 'fixtures' stamp: 'MU 5/29/2002 00:56'!
arrayWithEmptyStringXML
	^ ' <m:reverseArray
xmlns:m="http://www.mars.dti.ne.jp/~umejava/smalltalk/soapOpera/rpc/"
SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/"
xmlns:SOAP-ENC="http://schemas.xmlsoap.org/soap/encoding/"
xmlns:xsd="http://www.w3.org/2001/XMLSchema"
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/">
<anArray SOAP-ENC:arrayType="xsd:anyType[3]">
<item xsi:type="xsd:string">Hello</item>
<item xsi:type="xsd:string"></item>
<item xsi:type="xsd:string">Dolphin</item>
</anArray>
</m:reverseArray>
'! !

!SoapDecoderTestCase methodsFor: 'fixtures' stamp: 'MU 4/28/2002 01:11'!
complexDataXML
	"Google API like complex XML"
	^' <return xsi:type="ns1:GoogleSearchResult" xmlns:xsi="http://www.w3.org/1999/XMLSchema-instance" xmlns:xsd="http://www.w3.org/1999/XMLSchema">
   <documentFiltering xsi:type="xsd:boolean">false</documentFiltering>
   <estimatedTotalResultsCount xsi:type="xsd:int">1</estimatedTotalResultsCount>
   <directoryCategories xmlns:ns2="http://schemas.xmlsoap.org/soap/encoding/" xsi:type="ns2:Array" ns2:arrayType="ns1:DirectoryCategory[0]"></directoryCategories>
   <searchTime xsi:type="xsd:double">0.194871</searchTime>
   <resultElements xmlns:ns3="http://schemas.xmlsoap.org/soap/encoding/" xsi:type="ns3:Array" ns3:arrayType="ns1:ResultElement[1]">
     <item xsi:type="ns1:ResultElement">
  <cachedSize xsi:type="xsd:string">2k</cachedSize>
  <hostName xsi:type="xsd:string">somehost</hostName>
  <snippet xsi:type="xsd:string">snippet...</snippet>
  <directoryCategory xsi:type="ns1:DirectoryCategory">
    <specialEncoding xsi:type="xsd:string"></specialEncoding>
    <fullViewableName xsi:type="xsd:string"></fullViewableName>
  </directoryCategory>
  <relatedInformationPresent xsi:type="xsd:boolean">true</relatedInformationPresent>
  <directoryTitle xsi:type="xsd:string"></directoryTitle>
  <summary xsi:type="xsd:string"></summary>
  <URL xsi:type="xsd:string">http://www.squeak.org</URL>
  <title xsi:type="xsd:string">Squeak home page</title>
     </item>
   </resultElements>
   <endIndex xsi:type="xsd:int">1</endIndex>
   <searchTips xsi:type="xsd:string"></searchTips>
   <searchComments xsi:type="xsd:string"></searchComments>
   <startIndex xsi:type="xsd:int">1</startIndex>
   <estimateIsExact xsi:type="xsd:boolean">true</estimateIsExact>
   <searchQuery xsi:type="xsd:string">squeak</searchQuery>
 </return>'! !


TestCase subclass: #SoapEncArrayTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-TestCases'!

!SoapEncArrayTestCase methodsFor: 'testing' stamp: 'MU 3/24/2002 03:08'!
testArrayItemType
	| elem1 elem2 |
	elem1 := ((SoapVariable name: 'arr' value: #(1 2 3) ) asXmlElement).
	self should:[elem1 arrayItemType = (SoapConstants xsdPrefixColon, 'integer')].
	
	elem2 := ((SoapVariable name: 'arr' value: #(1 'two' 3) ) asXmlElement).
	self should:[elem2 arrayItemType = (SoapConstants xsdPrefixColon, 'anyType')].
	! !

!SoapEncArrayTestCase methodsFor: 'testing' stamp: 'MU 3/24/2002 01:49'!
testArraySize
	| elem1 elem2 |
	elem1 := ((SoapVariable name: 'arr' value: #(1 nil 3) ) asXmlElement).
	self should:[elem1 size = 3].
	
	elem2 := ((SoapVariable name: 'arr' value: #() ) asXmlElement).
	self should:[elem2 size = 0].
	! !

!SoapEncArrayTestCase methodsFor: 'testing' stamp: 'MU 8/6/2002 00:00'!
testArrayWithNamespace
	| elem1 |
	elem1 := ((SoapVariable name: 'arr' value: #(1 2 3) xsdType: 'ns1:myArrayType' namespace: 'http://my.com/nm') asXmlElement).
	self should:[(elem1 declaredNamespaceURIFor: 'ns1') = 'http://my.com/nm'].
	
	! !

!SoapEncArrayTestCase methodsFor: 'testing' stamp: 'MU 3/24/2002 00:22'!
testIsArrayType
	| elem1 elem2 |
	elem1 := ((SoapVariable name: 'arr' value: #(1 2 3) ) asXmlElement).
	self should:[elem1 isArrayType].
	
	elem2 := ((SoapVariable name: 'prim' value: 1 ) asXmlElement).
	self shouldnt:[elem2 isArrayType]
	! !


TestCase subclass: #SoapEncoderTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-TestCases'!

!SoapEncoderTestCase methodsFor: 'testing' stamp: 'mu 2/6/2002 01:42'!
testEncodeBase64Binary
	| enc ret bytes |
	enc := SoapEncoder new.

	bytes := ByteArray with: 1 with: 2 with: 3 with: 4.
	ret := enc encodeSoapVariable: (SoapVariable name: 'binbin' value: bytes).
	self should: [ (ret getAttributeNamed: 'xsi:type') = 'xsd:base64Binary'].
	self should: [ ret value = 'AQIDBA=='].
	
	
	
	
	
	! !

!SoapEncoderTestCase methodsFor: 'testing' stamp: 'mu 9/2/2001 01:11'!
testEncodeBoolean
	| enc ret |
	enc := SoapEncoder new.

	ret := enc encodeSoapVariable: (SoapVariable name: 'auau' value: 'true' type: #Boolean).
	self should: [ (ret getAttributeNamed: 'xsi:type') = 'xsd:boolean'].
	self should: [ ret value = 'true'].
	
	
	
	
	
	! !

!SoapEncoderTestCase methodsFor: 'testing' stamp: 'MU 4/27/2002 01:54'!
testEncodeComplexNamedStruct
	| element elems resultStruct enc var ret retResultElems retResultElem |
	element := SoapEncStruct
				fromDictionary: (Dictionary newFrom: {#summary -> 'summary of squeak'})
				named: 'ResultElement'.
	elems := SoapEncArray
				fromArray: (Array with: element)
				named: 'resultElements'
				elementType: 'ResultElement'.
	resultStruct := SoapEncStruct
				fromDictionary: (Dictionary newFrom: {#query -> 'squeak'. #resultElements -> elems})
				named: 'SearchResult'.
	enc := SoapEncoder new.
	var := SoapVariable name: 'return' value: resultStruct.
	ret := enc encodeSoapVariable: var.
	self should: [ret xsiType = 'SearchResult'].
	retResultElems := ret findChildNamed: 'resultElements'. 
	self should: [retResultElems notNil].
	self should:[(ret findChildNamed: 'query') value = 'squeak'].
	self should:[retResultElems isArrayType].
	self should:[retResultElems children size = 1].
	self should:[retResultElems children size = 1].
	retResultElem := retResultElems findChildNamed: 'item'.
	self should: [retResultElem notNil].
	self should: [retResultElem notNil].
	self should: [retResultElem xsiType = 'ResultElement'].
	self should: [(retResultElem findChildNamed: 'summary') value = 'summary of squeak'].
	
	
	
	! !

!SoapEncoderTestCase methodsFor: 'testing' stamp: 'MU 3/20/2002 00:48'!
testEncodeFloatArray
	| enc ret |
	enc := SoapEncoder new.

	ret := enc encodeSoapVariable: (SoapVariable name: 'floatArr' value: #(1.0 2.3 3.4)).
	self should: [ (ret getAttributeNamed: (SoapConstants soapEncPrefixColon, 'arrayType')) =  'xsd:float[3]'].
	self should: [ (ret children at: 1) value = '1.0'].
	self should: [ (ret children at: 3) value = '3.4'].
	
	ret := enc encodeSoapVariable: (SoapVariable name: 'integarArr' value: #(4.5 5.6) type: #Array).
	self should: [ (ret getAttributeNamed: (SoapConstants soapEncPrefixColon, 'arrayType')) =  'xsd:float[2]'].
	self should: [ (ret children at: 1) value = '4.5'].
	self should: [ (ret children at: 2) value = '5.6'].
	
	ret := enc encodeSoapVariable: (SoapVariable name: 'integarArr' value: #()).
	self should: [ (ret getAttributeNamed: (SoapConstants soapEncPrefixColon, 'arrayType')) =  'xsd:anyType[0]'].
	self should: [ ret children isEmpty].
	
	
	
	
	! !

!SoapEncoderTestCase methodsFor: 'testing' stamp: 'mu 9/2/2001 01:11'!
testEncodeInteger
	| enc ret |
	enc := SoapEncoder new.

	ret := enc encodeSoapVariable: (SoapVariable name: 'auau' value: 1).
	self should: [ (ret getAttributeNamed: 'xsi:type') = 'xsd:integer'].
	self should: [ ret value = '1'].
	
	ret := enc encodeSoapVariable: (SoapVariable name: 'auau' value: 10000000000 type: #Integer).
	self should: [ (ret getAttributeNamed: 'xsi:type') = 'xsd:integer'].
	self should: [ ret value = '10000000000'].
	
	
	
	! !

!SoapEncoderTestCase methodsFor: 'testing' stamp: 'MU 3/20/2002 00:39'!
testEncodeIntegerArray
	| enc ret |
	enc := SoapEncoder new.

	ret := enc encodeSoapVariable: (SoapVariable name: 'integarArr' value: #(1 2 3)).
	self should: [ (ret getAttributeNamed: (SoapConstants soapEncPrefixColon, 'arrayType')) =  'xsd:integer[3]'].
	self should: [ (ret children at: 1) value = '1'].
	self should: [ (ret children at: 3) value = '3'].
	
	ret := enc encodeSoapVariable: (SoapVariable name: 'integarArr' value: #(4 5) type: #Array).
	self should: [ (ret getAttributeNamed: (SoapConstants soapEncPrefixColon, 'arrayType')) =  'xsd:integer[2]'].
	self should: [ (ret children at: 1) value = '4'].
	self should: [ (ret children at: 2) value = '5'].
	
	ret := enc encodeSoapVariable: (SoapVariable name: 'integarArr' value: #()).
	self should: [ (ret getAttributeNamed: (SoapConstants soapEncPrefixColon, 'arrayType')) =  'xsd:anyType[0]'].
	self should: [ ret children isEmpty].
	
	
	
	
	! !

!SoapEncoderTestCase methodsFor: 'testing' stamp: 'mu 10/17/2002 19:10'!
testEncodeNil
	| originalUseNull enc ret |
	[originalUseNull := SoapEncoder useXsiNullAttribute.
	enc := SoapEncoder new.
	SoapEncoder useXsiNullAttribute: false.
	ret := enc
				encodeSoapVariable: (SoapVariable name: 'auau' value: nil).
	self
		should: [ret = nil].
	SoapEncoder useXsiNullAttribute: true.
	ret := enc
				encodeSoapVariable: (SoapVariable name: 'auau' value: nil).
	self
		should: [ret name = 'auau'].
	self
		should: [(ret getAttributeNamed: SoapConstants xsiNil)
				= 1]]
		ensure: [SoapEncoder useXsiNullAttribute: originalUseNull]! !

!SoapEncoderTestCase methodsFor: 'testing' stamp: 'MU 4/18/2003 17:08'!
testEncodeReferredValue
	| enc var1 var2 var3 ret1 ret2 ret3 |
	
	enc := SoapEncoder new. 

	var1 := SoapVariable name: 'master' value: #MASTER.
	var2 := SoapVariable name: 'valueRef' href:  var1.
	var2 value: #1.
	var3 := SoapVariable name: 'valueRefRef' href:  var2.
	var3 value: #2.
	
	ret1 := enc encodeSoapVariable: var1.
	self should: [ ret1 name = 'master'].
	self should: [ (ret1 getAttributeNamed: 'xsi:type') = 'xsd:string'].
	self should: [ ret1 value = 'MASTER'].
	self should: [ ret1 hasAttributeNamed: 'id'].
	
	ret2 := enc encodeSoapVariable: var2.
	self should: [ ret2 name = 'valueRef'].
	self shouldnt: [ (ret2 hasAttributeNamed: 'xsi:type')].
	self should: [ ret2 value isNil].
	self should: [ ret2 hasAttributeNamed: 'href'].
	self should: [ (ret2 getAttributeNamed: 'href') = ('#', (ret1 getAttributeNamed: 'id')) ].

	ret3 := enc encodeSoapVariable: var3.
	self should: [ ret3 name = 'valueRefRef'].
	self shouldnt: [ (ret3 hasAttributeNamed: 'xsi:type')].
	self should: [ ret3 value isNil].
	self should: [ ret3 hasAttributeNamed: 'href'].
	self should: [ (ret3 getAttributeNamed: 'href') = ('#', (ret2 getAttributeNamed: 'id')) ].
	
	
	
	! !

!SoapEncoderTestCase methodsFor: 'testing' stamp: 'MU 4/21/2002 01:49'!
testEncodeSimpleNamedStruct
	| enc ret dic struct |
	enc := SoapEncoder new.
	dic := Dictionary new.
	dic at: #varString put: 'hello'.
	dic at: #varInt put: 42.
	dic at: #varFloat put: 0.6.
	struct := SoapEncStruct fromDictionary: dic named: 'SearchResult'.

	ret := enc encodeSoapVariable: (SoapVariable name: 'inputStruct' value: struct).
	self should:[ret name = 'inputStruct'].
	self should:[ret xsiType = 'SearchResult'].
	self should:[ret children size = 3].
	self should:[(ret findChildNamed: 'varString') xsiType = SoapConstants xsdStringType].
	self should:[(ret findChildNamed: 'varInt') xsiType = SoapConstants xsdIntegerType].
	self should:[(ret findChildNamed: 'varFloat') xsiType = SoapConstants xsdFloatType].
	self should:[(ret findChildNamed: 'varString') value = 'hello'].
	self should:[(ret findChildNamed: 'varInt') value = '42'].
	self should:[(ret findChildNamed: 'varFloat') value = '0.6'].
	
	
	
	
	
	
	! !

!SoapEncoderTestCase methodsFor: 'testing' stamp: 'MU 4/21/2002 01:46'!
testEncodeSimpleStruct
	| enc ret dic |
	enc := SoapEncoder new.
	dic := Dictionary new.
	dic at: #varString put: 'hello'.
	dic at: #varInt put: 42.
	dic at: #varFloat put: 0.6.

	ret := enc encodeSoapVariable: (SoapVariable name: 'inputStruct' value: dic).
	self should:[ret name = 'inputStruct'].
	self should:[ret children size = 3].
	self should:[(ret findChildNamed: 'varString') xsiType = SoapConstants xsdStringType].
	self should:[(ret findChildNamed: 'varInt') xsiType = SoapConstants xsdIntegerType].
	self should:[(ret findChildNamed: 'varFloat') xsiType = SoapConstants xsdFloatType].
	self should:[(ret findChildNamed: 'varString') value = 'hello'].
	self should:[(ret findChildNamed: 'varInt') value = '42'].
	self should:[(ret findChildNamed: 'varFloat') value = '0.6'].
	
	
	
	
	
	
	! !

!SoapEncoderTestCase methodsFor: 'testing' stamp: 'MU 8/7/2002 23:02'!
testEncodeSimpleStructWithNamespace
	| enc ret dic struct |
	enc := SoapEncoder new.
	dic := Dictionary new.
	dic at: #varString put: 'hello'.
	dic at: #varInt put: 42.
	dic at: #varFloat put: 0.6.
	struct := SoapEncStruct fromDictionary: dic xsdType: 'ns2:SOAPStruct' namespace: 'http://www.aa.com/aaa' .

	ret := enc encodeSoapVariable: (SoapVariable name: 'inputStruct' value: struct).
	self should:[ret name = 'inputStruct'].
	self should:[(ret declaredNamespaceURIFor: 'ns2') = 'http://www.aa.com/aaa'].
	self should:[ret children size = 3].
	self should:[(ret findChildNamed: 'varString') xsiType = SoapConstants xsdStringType].
	self should:[(ret findChildNamed: 'varInt') xsiType = SoapConstants xsdIntegerType].
	self should:[(ret findChildNamed: 'varFloat') xsiType = SoapConstants xsdFloatType].
	self should:[(ret findChildNamed: 'varString') value = 'hello'].
	self should:[(ret findChildNamed: 'varInt') value = '42'].
	self should:[(ret findChildNamed: 'varFloat') value = '0.6'].
	
	
	
	
	
	
	! !

!SoapEncoderTestCase methodsFor: 'testing' stamp: 'mu 9/2/2001 01:11'!
testEncodeString
	| enc ret |
	enc := SoapEncoder new.

	ret := enc encodeSoapVariable: (SoapVariable name: 'auau' value: 'smalltalk').
	self should: [ (ret getAttributeNamed: 'xsi:type') = 'xsd:string'].
	self should: [ ret value = 'smalltalk'].
	
	ret := enc encodeSoapVariable: (SoapVariable name: 'auau' value: 'ruby' type: #String).
	self should: [ (ret getAttributeNamed: 'xsi:type') = 'xsd:string'].
	self should: [ ret value = 'ruby'].
	
	
	
	! !

!SoapEncoderTestCase methodsFor: 'testing' stamp: 'MU 7/28/2002 00:51'!
testEncodeStringArray
	| enc ret |
	enc := SoapEncoder new.

	ret := enc encodeSoapVariable: (SoapVariable name: 'stringArr' value: #('a' 'b' 'c')).
	self should: [ (ret getAttributeNamed: (SoapConstants soapEncPrefixColon, 'arrayType')) =  'xsd:string[3]'].
	self should: [ (ret children at: 1) value = 'a'].
	self should: [ (ret children at: 3) value = 'c'].
	
	ret := enc encodeSoapVariable: (SoapVariable name: 'stringArr' value: #('' 'eee') type: #Array).
	self should: [ (ret getAttributeNamed: (SoapConstants soapEncPrefixColon, 'arrayType')) =  'xsd:string[2]'].
	self should: [ (ret children at: 1) value = ''].
	self should: [ (ret children at: 2) value = 'eee'].
	
	ret := enc encodeSoapVariable: (SoapVariable name: 'stringArr' value: #()).
	self should: [ (ret getAttributeNamed: (SoapConstants soapEncPrefixColon, 'arrayType')) =  'xsd:anyType[0]'].
	self should: [ ret children isEmpty].
	
	
	
	
	! !


TestCase subclass: #SoapEnvelopeBuilderTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-TestCases'!

!SoapEnvelopeBuilderTestCase methodsFor: 'testing' stamp: 'mu 9/7/2003 19:56'!
testBuildClientSoapFaultEnvelope
	| builder env body fault |
	builder := SoapEnvelopeBuilder new.
	env := builder
				buildClientSoapFaultEnvelope: (ZeroDivide dividend: 'test zero divide').
	body := env body.
	self should: [body name = 'env:Body'].
	self should: [body hasFault].
	fault := body fault.
	self should: [fault name = 'env:Fault'].
	self should: [fault faultcode = 'env:Client'].
	
	! !

!SoapEnvelopeBuilderTestCase methodsFor: 'testing' stamp: 'mu 8/20/2001 00:40'!
testBuildEnvelope
	| builder env body methodElem argElem |
	builder := SoapEnvelopeBuilder new.
	env := builder buildSoapEnvelopeFromXmlString: (self echoInteger).

	self should: [env name = 'SOAP-ENV:Envelope'].
	self should:[ (env getAttributeNamed: 'SOAP-ENV:encodingStyle') = 'http://schemas.xmlsoap.org/soap/encoding/'].
	self should:[ (env getAttributeNamed: 'xmlns:SOAP-ENC') = 'http://schemas.xmlsoap.org/soap/encoding/'].
	self should:[ (env getAttributeNamed: 'xmlns:SOAP-ENV') = 'http://schemas.xmlsoap.org/soap/envelope/'].
	self should:[ (env getAttributeNamed: 'xmlns:xsd') = 'http://www.w3.org/2001/XMLSchema'].
	self should:[ (env getAttributeNamed: 'xmlns:xsi') = 'http://www.w3.org/2001/XMLSchema-instance'].
	
	body := env body.
	self should: [body name = 'SOAP-ENV:Body'].
	
	methodElem := body findBodyEntryNamed: 'm:echoInteger'.
	self should: [methodElem notNil].
	self should: [methodElem name = 'm:echoInteger'].
	self should: [(methodElem getAttributeNamed: 'xmlns:m') = 'http://soapinterop.org/'].
	
	argElem := methodElem children first.
	self should: [argElem name =  'inputInteger'].
	self should: [argElem value = '42'].
	
	
	
	
	! !

!SoapEnvelopeBuilderTestCase methodsFor: 'testing' stamp: 'mu 8/20/2001 01:09'!
testInheritedEnvelopeEncoding
	| builder env body methodElem argElem |
	builder := SoapEnvelopeBuilder new.
	env := builder buildSoapEnvelopeFromXmlString: (self echoBoolean).

	self should: [env name = 'SOAP-ENV:Envelope'].
	self should:[env encodingStyleURIs =  #('http://schemas.xmlsoap.org/soap/encoding/')].	

	body := env body.
	self should: [body name = 'SOAP-ENV:Body'].
	
	methodElem := body findBodyEntryNamed: 'm:echoBoolean'.
	self should: [methodElem notNil].
	self should: [methodElem name = 'm:echoBoolean'].
	self should: [(methodElem getAttributeNamed: 'xmlns:m') = 'http://soapinterop.org/'].	
	
	argElem := methodElem children first.
	self should:[argElem encodingStyleURIs =  #('http://schemas.xmlsoap.org/soap/encoding/')].
	self should: [argElem name =  'inputBoolean'].
	self should: [argElem value = '1'].
	
	
	
	
	! !


!SoapEnvelopeBuilderTestCase methodsFor: 'fixtures' stamp: 'mu 8/20/2001 01:04'!
echoBoolean
	"From ROUND 2 SOAP Interoperability Tests Specification"
	"http://www.whitemesa.com/interop/proposal2.html#echoInteger"

	^'<?xml version="1.0" encoding="UTF-8"?>

<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" xmlns:SOAP-ENC="http://schemas.xmlsoap.org/soap/encoding/" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Body>
<m:echoBoolean xmlns:m="http://soapinterop.org/">
<inputBoolean>1</inputBoolean>
</m:echoBoolean>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>'
! !

!SoapEnvelopeBuilderTestCase methodsFor: 'fixtures' stamp: 'mu 8/20/2001 00:14'!
echoInteger
	
	"From ROUND 2 SOAP Interoperability Tests Specification"
	"http://www.whitemesa.com/interop/proposal2.html#echoInteger"

	^'<?xml version="1.0" encoding="UTF-8"?>

<SOAP-ENV:Envelope SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/" xmlns:SOAP-ENC="http://schemas.xmlsoap.org/soap/encoding/" xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
<SOAP-ENV:Body>
<m:echoInteger xmlns:m="http://soapinterop.org/">
<inputInteger>42</inputInteger>
</m:echoInteger>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>'
! !


TestCase subclass: #SoapEnvelopeTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-TestCases'!

!SoapEnvelopeTestCase methodsFor: 'testing' stamp: 'mu 5/3/2001 18:27'!
testEnvelopeMustUnderstand
	| env |
	env := SoapEnvelope new.
	self should: [env body isMustUnderstandEnabled].
	env addHeader.
	env header disableMustUnderstand.
	self shouldnt: [env body isMustUnderstandEnabled].
	
	
! !

!SoapEnvelopeTestCase methodsFor: 'testing' stamp: 'mu 12/31/2001 01:50'!
testEnvelopeTypicalEncodingStyle
	| env body |
	env := SoapEnvelope new.
	env declareSoapEncEncoding.
	self should: [ (env getAttributeNamed: (SoapConstants soapEnvPrefix,':', SoapConstants encodingStyle) ) 
			= SoapConstants soapEncURI].
	self should: [env encodingStyleURIs = (Array with: (SoapConstants soapEncURI))].
	
	body := env addBody.
	self should: [body encodingStyleURIs = (Array with: (SoapConstants soapEncURI))].
	
	
	
	
	
	
! !


TestCase subclass: #SoapExceptionBuilderTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-TestCases'!

!SoapExceptionBuilderTestCase methodsFor: 'testing' stamp: 'mu 9/7/2003 20:03'!
testMessageNotUnderstoodSignal
	
	| fault builder exception |
	fault := self messageNotUnderstoodFault.
	builder := SoapExceptionBuilder new.
	exception := builder buildExceptionFrom: fault.
	self should: [exception tag = '<<signaled in server>>'].
	self should: [exception messageText =  'UndefinedObject>>add:'].
	self should:[exception signal] raise: MessageNotUnderstood.
	
	
	! !

!SoapExceptionBuilderTestCase methodsFor: 'testing' stamp: 'mu 11/24/2001 01:47'!
testNotExistErrorClassSignal
	
	| fault builder |
	fault := self fooBarBazFault.
	builder := SoapExceptionBuilder new.
	
	self should:[builder buildExceptionFrom: fault] raise: SoapNoSuchExceptionClass.
	
	
	! !

!SoapExceptionBuilderTestCase methodsFor: 'testing' stamp: 'mu 11/24/2001 01:42'!
testZeroDivideSignal
	
	| fault builder exception |
	fault := self zeroDivideFault.
	builder := SoapExceptionBuilder new.
	exception := builder buildExceptionFrom: fault.
	self should:[exception signal] raise: ZeroDivide.
	! !


!SoapExceptionBuilderTestCase methodsFor: 'fixtures' stamp: 'mu 11/24/2001 01:33'!
fooBarBazFault
	| soapFault  details stErrorClass messageText detail | 
	soapFault := SoapFault new.
	details := SoapWrapElement named: 'details' withPrefix: 'e'.
	stErrorClass := details createChildNamed: 'ErrorClass'.
	stErrorClass value: 'FooBarBaz'.
	messageText := details createChildNamed: 'messageText'.
	messageText value: 'invalid not existing class'.
	detail := soapFault addDetail.
	detail addSubElement: details.
	^soapFault! !

!SoapExceptionBuilderTestCase methodsFor: 'fixtures' stamp: 'mu 11/24/2001 01:35'!
messageNotUnderstoodFault
	^ [nil add: 1 ]
		on: MessageNotUnderstood
		do: [:ex | 
			| soapFault soapFaultDetailBuilder | 
			soapFault := SoapFault new.
			soapFaultDetailBuilder := SoapFaultDetailBuilder new.
			soapFaultDetailBuilder buildSoapFaultDetailOn: soapFault from: ex.
			ex return: soapFault]! !

!SoapExceptionBuilderTestCase methodsFor: 'fixtures' stamp: 'mu 11/24/2001 01:24'!
zeroDivideFault
	^ [1 / 0]
		on: ZeroDivide
		do: [:ex | 
			| soapFault soapFaultDetailBuilder | 
			soapFault := SoapFault new.
			soapFaultDetailBuilder := SoapFaultDetailBuilder new.
			soapFaultDetailBuilder buildSoapFaultDetailOn: soapFault from: ex.
			ex return: soapFault]! !


TestCase subclass: #SoapFaultTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-TestCases'!

!SoapFaultTestCase methodsFor: 'testing' stamp: 'mu 2/1/2002 00:10'!
testBasicFault
	
	| fault detail |
	fault := SoapFault client faultstring: 'Client Error!!'.
	self should: [fault faultcode = (SoapConstants soapEnvPrefixColon, SoapConstants client)].
	self should: [fault faultstring = 'Client Error!!'].
	
	detail := fault addDetail.
	self should: [detail  name = 'detail'].
	
	
	
	
	! !

!SoapFaultTestCase methodsFor: 'testing' stamp: 'mu 5/6/2001 01:46'!
testDetailedFault
	| fault detail myErrors myErrors2 message errorcode |
	fault := SoapFault client faultstring: 'Client Error!!'.
	detail := fault addDetail.
	myErrors := detail addSubElement: (SoapWrapElement named: 'myErrors' withPrefix: 'e').
	myErrors declareNamespace: 'e' uri: 'http://www.mars.dti.ne.jp/~umejava/smalltalk/SoapOpera/errors'.
	(myErrors createChildNamed: 'message') value: 'My application didn''t work'.
	(myErrors createChildNamed: 'errorcode') value: '1001'.
	
	myErrors2 := (fault detail findSubElementNamed: 'e:myErrors'). "##Apparently more work needed##"
	message := myErrors2 children at: 1.
	errorcode := myErrors2 children at: 2.
	
	self should:[message value = 'My application didn''t work'].
	self should:[errorcode value = '1001'].
	
	
	
	
	! !

!SoapFaultTestCase methodsFor: 'testing' stamp: 'mu 2/1/2002 00:13'!
testMinorFaultCodes
	| fault |
	"##OBSOLETE## hierarchical notation is no longer used in SOAP1.2"

	fault := SoapFault client faultstring: 'Client Error!!'.
	fault attachMinorFaultCodes: #('Authentication' 'Password' 'Expired').
		
	self should:[fault faultcode = (SoapConstants soapEnvPrefixColon, 'Client.Authentication.Password.Expired')].
	
	
	
	
	
	! !


TestCase subclass: #SoapHeaderTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-TestCases'!

!SoapHeaderTestCase methodsFor: 'testing' stamp: 'mu 4/22/2001 02:36'!
testMustUnderstand
	| header |
	header := SoapHeader new.
	self shouldnt: [header isMustUnderstandEnabled].	
	header enableMustUnderstand.
	self should: [header isMustUnderstandEnabled].	
	header disableMustUnderstand.
	self shouldnt: [header isMustUnderstandEnabled].	! !


TestCase subclass: #SoapHttpClientTestCase
	instanceVariableNames: 'originalTransports '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-TestCases'!

!SoapHttpClientTestCase methodsFor: 'running' stamp: 'MU 4/18/2003 17:21'!
setUp
	originalTransports  := SoapServerSetup runningTransportNames.
	SoapServerSetup startOnly: #(http) ! !

!SoapHttpClientTestCase methodsFor: 'running' stamp: 'MU 4/18/2003 17:21'!
tearDown
	
	SoapServerSetup startOnly: originalTransports ! !


!SoapHttpClientTestCase methodsFor: 'testing' stamp: 'MU 4/18/2003 17:21'!
testErrorEnvelopeSend
	
	| curPort retXML envelope body prefix fault |
	SoapServerSetup startOnly: #(http).
	SoapServiceHandler default add: self simpleService.
	curPort := SoapSetting defaultPortAt: #http.
	
	retXML := (SoapHttpClient url: 'http://localhost:', curPort printString, '/' ) send: self errorEnvelope.
	envelope := SoapEnvelopeBuilder new buildSoapEnvelopeFromXmlString: retXML.
	
	self should:[envelope isKindOf: SoapEnvelope].
	body := envelope body.
	self should:[ body hasFault].
	fault := body fault.
	prefix := SoapConstants soapEnvPrefixColon.
	self should:[ fault name = (prefix, 'Fault')].
	self should:[ fault faultcode =  (prefix,'Client')].
	self should:[ fault faultstring  =  'SoapNoSuchService: DoSomeOtherThing'].
	SoapServiceHandler default remove: self simpleService.
	! !

!SoapHttpClientTestCase methodsFor: 'testing' stamp: 'MU 4/18/2003 17:21'!
testSimpleEnvelopeSend
	
	| curPort retXML envelope body method |
	SoapServerSetup startOnly: #(http).
	SoapServiceHandler default add: self simpleService.
	curPort := SoapSetting defaultPortAt: #http.
	
	retXML := (SoapHttpClient url: 'http://localhost:', curPort printString, '/' ) send: self simpleEnvelope.
	envelope := SoapEnvelopeBuilder new buildSoapEnvelopeFromXmlString: retXML.
	
	self should:[envelope isKindOf: SoapEnvelope].
	body := envelope body.
	self shouldnt:[ body hasFault].
	method := body bodyEntries first.
	self should:[ method name = 'm:addResponse'].
	self should:[ (method findChildNamed: 'result' ) value = 'newElement'].
	
	SoapServiceHandler default remove: self simpleService.
	! !


!SoapHttpClientTestCase methodsFor: 'fixtures' stamp: 'mu 2/1/2002 00:21'!
errorEnvelope
	
	^'

<env:Envelope

	xmlns:env="http://schemas.xmlsoap.org/soap/envelope/"

	env:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">

	<env:Body>

		<m:DoSomeOtherThing xmlns:m="urn:stSoap:Person1234">

			<symbol>DIS</symbol>

		</m:DoSomeOtherThing>

	</env:Body>

</env:Envelope>

' copy.
! !

!SoapHttpClientTestCase methodsFor: 'fixtures' stamp: 'mu 2/1/2002 00:21'!
simpleEnvelope
	
	^'

<env:Envelope

	xmlns:env="http://schemas.xmlsoap.org/soap/envelope/"

	env:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">

	<env:Body>

		<m:add xmlns:m="http://www.mars.dti.ne.jp/~umejava/smalltalk/soapOpera/">

			<newElem>newElement</newElem>

		</m:add>

	</env:Body>

</env:Envelope>

' copy.
! !

!SoapHttpClientTestCase methodsFor: 'fixtures' stamp: 'mu 12/28/2001 19:50'!
simpleService
	| ord serv |
	ord := OrderedCollection new.
	serv := SoapService implementor: ord selector: #add:.
	serv signature: (SoapServiceSignature name: 'add' paramNames: #(newElem)).
	^serv! !


TestCase subclass: #SoapNullDecoderTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-TestCases'!

!SoapNullDecoderTestCase methodsFor: 'testing' stamp: 'MU 10/25/2002 01:11'!
testDecodeBoolean
	| dec ret |
	dec := SoapNullDecoder new.
	ret := dec decodeXmlElement: ((SoapVariable
					name: 'arg1'
					value: true) encoding: #nullEncoding;
					 asXmlElement).
	self
		should: [ret = true]! !

!SoapNullDecoderTestCase methodsFor: 'testing' stamp: 'MU 10/25/2002 01:12'!
testDecodeInteger
	| dec ret |
	dec := SoapNullDecoder new.
	ret := dec decodeXmlElement: ((SoapVariable
					name: 'arg1'
					value: 1234567) encoding: #nullEncoding;
					 asXmlElement).
	self
		should: [ret = 1234567]! !

!SoapNullDecoderTestCase methodsFor: 'testing' stamp: 'MU 10/25/2002 01:12'!
testDecodeObject
	| dec ret dict |
	dec := SoapNullDecoder new.
	dict := Dictionary new.
	dict at: #Smalltalk put: #Cool.
	dict at: #Java put: #Plain.
	ret := dec decodeXmlElement: ((SoapVariable name: 'arg1' value: dict) encoding: #nullEncoding;
					 asXmlElement).
	self
		should: [ret = dict]! !

!SoapNullDecoderTestCase methodsFor: 'testing' stamp: 'MU 10/25/2002 01:13'!
testDecodeString
	| dec ret |
	dec := SoapNullDecoder new.
	ret := dec decodeXmlElement: ((SoapVariable
					name: 'arg1'
					value: 'Smalltalk') encoding: #nullEncoding;
					 asXmlElement).
	self
		should: [ret = 'Smalltalk']! !


TestCase subclass: #SoapNullEncoderTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-TestCases'!

!SoapNullEncoderTestCase methodsFor: 'testing' stamp: 'MU 10/25/2002 01:02'!
testEncodingInteger
	| enc ret |
	enc := SoapNullEncoder new.

	ret := enc encodeSoapVariable: (SoapVariable name: 'auau' value: 1).
	self should: [ (ret getAttributeNamed: 'xsi:type') = 'Null-ENC:SmallInteger'].
	self should: [ ret value = 1].
	
	ret := enc encodeSoapVariable: (SoapVariable name: 'auau' value: 10000000000 type: #Integer).
	self should: [ (ret getAttributeNamed: 'xsi:type') =  'Null-ENC:LargePositiveInteger'].
	self should: [ ret value = 10000000000].
	! !

!SoapNullEncoderTestCase methodsFor: 'testing' stamp: 'MU 10/25/2002 01:05'!
testEncodingNil
	| enc ret |
	enc := SoapNullEncoder new.
	
	ret := enc encodeSoapVariable: (SoapVariable name: 'auau' value: nil).
	self should: [ ret name = 'auau'].
	self should: [ (ret getAttributeNamed: 'xsi:type') = 'Null-ENC:UndefinedObject'].
	self should: [ ret value isNil].
	! !

!SoapNullEncoderTestCase methodsFor: 'testing' stamp: 'MU 10/25/2002 01:07'!
testEncodingObject
	
	| enc obj ret |
	enc := SoapNullEncoder new.
	obj := #(1 2 #(#hello 'Smalltalk') 3).
	ret := enc encodeSoapVariable: (SoapVariable name: 'auau' value: obj).
	self should: [ ret name = 'auau'].
	self should: [ (ret getAttributeNamed: 'xsi:type') =  'Null-ENC:Array'].
	self should: [ ret value = obj].! !

!SoapNullEncoderTestCase methodsFor: 'testing' stamp: 'MU 10/25/2002 01:08'!
testEncodingString
	| enc ret |
	enc := SoapNullEncoder new.

	ret := enc encodeSoapVariable: (SoapVariable name: 'auau' value: 'smalltalk').
	self should: [ (ret getAttributeNamed: 'xsi:type') = 'Null-ENC:String'].
	self should: [ ret value = 'smalltalk'].
	
	ret := enc encodeSoapVariable: (SoapVariable name: 'auau' value: 'ruby' type: #String).
	self should: [ (ret getAttributeNamed: 'xsi:type') = 'Null-ENC:String'].
	self should: [ ret value = 'ruby'].! !


TestCase subclass: #SoapServiceHandlerTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-TestCases'!

!SoapServiceHandlerTestCase methodsFor: 'testing' stamp: 'mu 1/27/2002 02:14'!
testDispatchError

	| handler env fault details |
	handler := SoapServiceHandler new. 
	handler add: self simpleService.
	env := self errorEnvelope.
	"self shouldnt:[env := handler dispatch: env with: self simpleContext.] raise: Error."
	env := handler dispatch: env with: self simpleContext.
	self assert:( env body hasFault).
	
	fault := env body fault.
	
	self should: [fault name = 'env:Fault'].
	self should: [fault faultcode =  'env:Client'].
	self should: [fault faultstring =  'SoapNoSuchService: /OrderedCollection:adddd'].
	
	details := fault detail subElements first.
	self should: [details shortName = 'details'].
	self should: [(details declaredNamespaceURIFor: SoapFaultDetailBuilder defaultPrefix)
				= SoapFaultDetailBuilder defaultNamespace].
	
	self should:[ (details findChildNamed: 'ErrorClass') value =  'SoapNoSuchService'].
	

	! !

!SoapServiceHandlerTestCase methodsFor: 'testing' stamp: 'mu 1/27/2002 02:18'!
testDispatchSimple
	| handler env ret |
	handler := SoapServiceHandler new.
	handler add: self simpleService.
	env := handler dispatch: self simpleEnvelope with: self simpleContext.
	self shouldnt:[env body hasFault].

	ret := env body bodyEntries first.
	
	self should:[ ret name = 'm:addResponse'].
	self should: [ ret encodingStyleURIs = #('http://schemas.xmlsoap.org/soap/encoding/')].
	self should:[ret firstChild xsiType = 'xsd:string'].
	self should:[ ret firstChild value = '1'].
	
	

	! !

!SoapServiceHandlerTestCase methodsFor: 'testing' stamp: 'mu 1/27/2002 02:19'!
testDispatchSimpleWithXsdType
	| handler env ret |
	handler := SoapServiceHandler new.
	handler add: self simpleService.
	env := handler dispatch: self simpleEnvelopeWithXsdType with: self simpleContext.
	self shouldnt:[env body hasFault].
	ret := env body bodyEntries first.

	self should:[ ret name = 'm:addResponse'].
	self should: [ ret encodingStyleURIs = #('http://schemas.xmlsoap.org/soap/encoding/')].
	self should:[ret firstChild xsiType = 'xsd:float'].
	self should:[ ret firstChild value = '1.02'].
	
	! !

!SoapServiceHandlerTestCase methodsFor: 'testing' stamp: 'mu 11/3/2001 21:50'!
testDispatchSoapNoSuchServiceError

	| handler env fault |
	handler := SoapServiceHandler new.
	handler add: self simpleService.
	env := self errorEnvelope.
	self shouldnt:[env := handler dispatch: env with: self simpleContext.] raise: Error.
	self assert:( env body hasFault).
	
	fault := env body fault.
	
	

	! !

!SoapServiceHandlerTestCase methodsFor: 'testing' stamp: 'mu 10/27/2001 18:34'!
testInvokeSimple
	| handler ret |
	handler := SoapServiceHandler new.
	handler add: self simpleService.
	ret := handler invoke: self simpleEnvelope with: self simpleContext.
	
	self should:[ret = '1'].
	! !

!SoapServiceHandlerTestCase methodsFor: 'testing' stamp: 'mu 10/27/2001 18:35'!
testInvokeSimpleWithXsdType
	| handler ret |
	handler := SoapServiceHandler new.
	handler add: self simpleService.
	ret := handler invoke: self simpleEnvelopeWithXsdType with: self simpleContext.
	
	self should:[ret = 1.02].
	
	! !


!SoapServiceHandlerTestCase methodsFor: 'fixtures' stamp: 'mu 12/27/2001 23:44'!
defaultTargetObjectURI
	
	^'http://www.fooServer.com/OrderedCollection'
	! !

!SoapServiceHandlerTestCase methodsFor: 'fixtures' stamp: 'mu 11/3/2001 20:32'!
errorEnvelope
	| xmlStr env |
	xmlStr := self errorEnvelopeXml.
	env := SoapEnvelopeBuilder new buildSoapEnvelopeFromXmlString: xmlStr.
	^env! !

!SoapServiceHandlerTestCase methodsFor: 'fixtures' stamp: 'mu 11/3/2001 20:33'!
errorEnvelopeXml
	^'<?xml version="1.0" encoding="UTF-8"?>

<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" xmlns:SOAP-ENC="http://schemas.xmlsoap.org/soap/encoding/" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Body>
<m:adddd xmlns:m="http://soapinterop.org/">
<newElem>1</newElem>
</m:adddd>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>'
! !

!SoapServiceHandlerTestCase methodsFor: 'fixtures' stamp: 'mu 12/27/2001 23:44'!
simpleContext
	
	^SoapContext new targetObjectURI: self defaultTargetObjectURI
	! !

!SoapServiceHandlerTestCase methodsFor: 'fixtures' stamp: 'mu 9/18/2001 20:12'!
simpleEnvelope
	| xmlStr env |
	xmlStr := self simpleEnvelopeXml.
	env := SoapEnvelopeBuilder new buildSoapEnvelopeFromXmlString: xmlStr.
	^env! !

!SoapServiceHandlerTestCase methodsFor: 'fixtures' stamp: 'mu 10/6/2001 21:05'!
simpleEnvelopeWithXsdType
	| xmlStr env |
	xmlStr := self simpleEnvelopeXmlWithXsdType.
	env := SoapEnvelopeBuilder new buildSoapEnvelopeFromXmlString: xmlStr.
	^env! !

!SoapServiceHandlerTestCase methodsFor: 'fixtures' stamp: 'mu 9/18/2001 21:37'!
simpleEnvelopeXml
	^'<?xml version="1.0" encoding="UTF-8"?>

<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" xmlns:SOAP-ENC="http://schemas.xmlsoap.org/soap/encoding/" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Body>
<m:add xmlns:m="http://soapinterop.org/">
<newElem>1</newElem>
</m:add>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>'
! !

!SoapServiceHandlerTestCase methodsFor: 'fixtures' stamp: 'mu 10/6/2001 21:05'!
simpleEnvelopeXmlWithXsdType
	^'<?xml version="1.0" encoding="UTF-8"?>

<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" xmlns:SOAP-ENC="http://schemas.xmlsoap.org/soap/encoding/" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/">
<SOAP-ENV:Body>
<m:add xmlns:m="http://soapinterop.org/">
<newElem xsi:type="xsd:float">1.02</newElem>
</m:add>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>'
! !

!SoapServiceHandlerTestCase methodsFor: 'fixtures' stamp: 'mu 12/27/2001 23:45'!
simpleService
	| ord serv |
	ord := OrderedCollection new.
	serv := SoapService implementor: ord selector: #add:.
	serv signature: (SoapServiceSignature name: 'add' paramNames: #(newElem)).
	serv targetObjectURI: self defaultTargetObjectURI.
	^serv! !


TestCase subclass: #SoapServiceTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-TestCases'!

!SoapServiceTestCase methodsFor: 'testing' stamp: 'mu 10/6/2001 20:09'!
testInvole
	
	| ord serv |
	ord := OrderedCollection new.
	serv := SoapService  implementor: ord selector: #add:.
	serv signature: (SoapServiceSignature name: 'add' paramNames: #(newObject)).
	serv invoke: ((SoapServiceSignature name: 'add' paramNames: #(newObject)) valueAt: #newObject put: #bar).
	self should: [ord size = 1].
	self should:[ord first = #bar]
	
	
	 ! !

!SoapServiceTestCase methodsFor: 'testing' stamp: 'mu 10/6/2001 20:09'!
testInvoleFail
	| ord serv |
	ord := OrderedCollection new.
	serv := SoapService implementor: ord selector: #add:.
	serv
		signature: (SoapServiceSignature name: 'add' paramNames: #(#newObject )).
	self
		should: [serv
				invoke: ((SoapServiceSignature name: 'auau' paramNames: #(#newObject ))
						valueAt: #newObject
						put: #bar)]
		raise: SoapNoSuchService! !

!SoapServiceTestCase methodsFor: 'testing' stamp: 'mu 10/6/2001 20:09'!
testInvoleInvalidParamName
	| ord serv |
	ord := OrderedCollection new.
	serv := SoapService implementor: ord selector: #add:.
	serv
		signature: (SoapServiceSignature name: 'add' paramNames: #(#newObject )).
	self
		should: [serv
				invoke: ((SoapServiceSignature name: 'add' paramNames: #(#newObject ))
						valueAt: #auauObject
						put: #bar)]
		raise: SoapInvalidParamName! !

!SoapServiceTestCase methodsFor: 'testing' stamp: 'mu 10/6/2001 20:09'!
testInvoleTwoArgs

	| dict serv regSig perSig |
	dict := Dictionary new.
	serv := SoapService implementor: dict selector: #at:put:.
	regSig := SoapServiceSignature name: 'at put'  paramNames: #(index value).
	serv signature: regSig.
	
	perSig := SoapServiceSignature name: 'at put' paramNames: #(index value).
	perSig valueAt: #index put: 1.
	perSig valueAt: #value put: #bar.
	serv invoke: perSig.
	
	self should: [dict includesKey: 1].
	self should:[(dict at: 1 ) = #bar]
	
	
	 ! !


TestCase subclass: #SoapSqDecoderTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-TestCases'!

!SoapSqDecoderTestCase methodsFor: 'testing' stamp: 'mu 12/28/2001 18:18'!
testDecodeBoolean
	| dec ret |
	dec := SoapSqDecoder new.
	ret := dec decodeXmlElement: ((SoapVariable
					name: 'arg1'
					value: 'true'
					type: #Boolean) encoding: #soapSqEncoding;
					 asXmlElement).
	self
		should: [ret = true]! !

!SoapSqDecoderTestCase methodsFor: 'testing' stamp: 'mu 12/28/2001 18:19'!
testDecodeInteger
	| dec ret |
	dec := SoapSqDecoder new.
	ret := dec decodeXmlElement: ((SoapVariable
					name: 'arg1'
					value: '1234567'
					type: #Integer) encoding: #soapSqEncoding;
					 asXmlElement).
	self
		should: [ret = 1234567]! !

!SoapSqDecoderTestCase methodsFor: 'testing' stamp: 'mu 12/28/2001 18:20'!
testDecodeObject
	| dec ret dict |
	dec := SoapSqDecoder new.
	dict := Dictionary new.
	dict at: #Smalltalk put: #Cool.
	dict at: #Java put: #Plain.
	ret := dec decodeXmlElement: ((SoapVariable name: 'arg1' value: dict) encoding: #soapSqEncoding;
					 asXmlElement).
	self
		should: [ret = dict]! !

!SoapSqDecoderTestCase methodsFor: 'testing' stamp: 'mu 12/28/2001 18:20'!
testDecodeString
	| dec ret |
	dec := SoapSqDecoder new.
	ret := dec decodeXmlElement: ((SoapVariable
					name: 'arg1'
					value: 'Smalltalk'
					type: #String) encoding: #soapSqEncoding;
					 asXmlElement).
	self
		should: [ret = 'Smalltalk']! !


TestCase subclass: #SoapSqEncoderTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-TestCases'!

!SoapSqEncoderTestCase methodsFor: 'testing' stamp: 'mu 7/2/2001 00:13'!
testEncodingInteger
	| enc ret |
	enc := SoapSqEncoder new.

	ret := enc encodeSoapVariable: (SoapVariable name: 'auau' value: 1).
	self should: [ (ret getAttributeNamed: 'xsi:type') = 'xsd:integer'].
	self should: [ ret value = '1'].
	
	ret := enc encodeSoapVariable: (SoapVariable name: 'auau' value: 10000000000 type: #Integer).
	self should: [ (ret getAttributeNamed: 'xsi:type') = 'xsd:integer'].
	self should: [ ret value = '10000000000'].
	
	
	
	! !

!SoapSqEncoderTestCase methodsFor: 'testing' stamp: 'mu 7/2/2001 00:20'!
testEncodingNil
	| enc ret |
	enc := SoapSqEncoder new.
	
	ret := enc encodeSoapVariable: (SoapVariable name: 'auau' value: nil).
	self should: [ ret name = 'auau'].
	self should: [ (ret getAttributeNamed: 'xsi:null') = 1].
	self should: [ ret isEmptyBody].
	
	
	
	
	
	! !

!SoapSqEncoderTestCase methodsFor: 'testing' stamp: 'mu 1/27/2002 02:33'!
testEncodingObject
	
	| enc obj ret byteStr oStr val |
	enc := SoapSqEncoder new.
	obj := #(1 2 #(#hello 'Smalltalk') 3).
	ret := enc encodeSoapVariable: (SoapVariable name: 'auau' value: obj).
	self should: [ ret name = 'auau'].
	self should: [ (ret getAttributeNamed: 'xsi:type') = 'Squeak-ENC:ReferenceStream'].
	
	byteStr := (Base64MimeConverter mimeDecodeToBytes: (ReadStream on: ret value)).
	oStr := SmartRefStream on: byteStr.
	val := oStr next.

	self should: [ obj = val].
	
	
	
	
	! !

!SoapSqEncoderTestCase methodsFor: 'testing' stamp: 'mu 7/2/2001 00:14'!
testEncodingString
	| enc ret |
	enc := SoapSqEncoder new.

	ret := enc encodeSoapVariable: (SoapVariable name: 'auau' value: 'smalltalk').
	self should: [ (ret getAttributeNamed: 'xsi:type') = 'xsd:string'].
	self should: [ ret value = 'smalltalk'].
	
	ret := enc encodeSoapVariable: (SoapVariable name: 'auau' value: 'ruby' type: #String).
	self should: [ (ret getAttributeNamed: 'xsi:type') = 'xsd:string'].
	self should: [ ret value = 'ruby'].
	
	
	
	! !


TestCase subclass: #SoapVariableTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-TestCases'!

!SoapVariableTestCase methodsFor: 'testing' stamp: 'mu 1/27/2002 02:32'!
testAsXmlElementSimple
	| inst elem |
	inst := SoapVariable name: 'foo' value: 1 type: #Integer.
	elem := inst asXmlElement.
	self should: [elem name = 'foo'].
	self should:[ elem parent = nil].
	self should:[ (elem getAttributeNamed: 'xsi:type') = 'xsd:integer']. 
	self should:[ (elem getAttributeNamed: 'env:encodingStyle') = SoapConstants soapEncURI]. 
	 ! !

!SoapVariableTestCase methodsFor: 'testing' stamp: 'mu 1/27/2002 02:33'!
testAsXmlElementSimpleSq
	| inst elem |
	inst := SoapVariable name: 'foo' value: 1 type: #Integer.
	inst encoding: #soapSqEncoding.
	elem := inst asXmlElement.
	self should: [elem name = 'foo'].
	self should:[ elem parent = nil].
	self should:[ (elem getAttributeNamed: 'xsi:type') = 'xsd:integer']. 
	self should:[ (elem getAttributeNamed: 'env:encodingStyle') = SoapConstants soapSqEncURI]. ! !


TestCase subclass: #SoapWrapElementTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SOAP-TestCases'!

!SoapWrapElementTestCase methodsFor: 'testing' stamp: 'mu 8/20/2001 00:07'!
testFromXmlElement
	
	| sdom elem body callElem argElem |
	sdom := SoXmlUtil parseXml: self echoString.
	elem := SoapWrapElement fromXmlElement: sdom.
	self should: [elem name = 'SOAP-ENV:Envelope'].
	self should: [(elem getAttributeNamed: 'SOAP-ENV:encodingStyle' ) = 'http://schemas.xmlsoap.org/soap/encoding/'].
	self should: [(elem getAttributeNamed: 'xmlns:SOAP-ENC' ) = 'http://schemas.xmlsoap.org/soap/encoding/'].
	self should: [(elem getAttributeNamed: 'xmlns:SOAP-ENV' ) = 'http://schemas.xmlsoap.org/soap/envelope/'].
	self should: [(elem getAttributeNamed: 'xmlns:xsd' ) = 'http://www.w3.org/2001/XMLSchema'].
	self should: [(elem getAttributeNamed: 'xmlns:xsi' ) = 'http://www.w3.org/2001/XMLSchema-instance'].
	
	body := elem children first.
	self should: [body name = 'SOAP-ENV:Body'].
	
	callElem := body children first.
	self should: [callElem name = 'm:echoString'].
	self should: [(callElem getAttributeNamed: 'xmlns:m' ) = 'http://soapinterop.org/'].
	
	argElem := callElem children first.
	self should: [argElem name = 'inputString'].
	self should: [argElem value = 'hello world'].
	"elem inspect."
	
	! !


!SoapWrapElementTestCase methodsFor: 'fixtures' stamp: 'mu 8/12/2001 18:01'!
echoString
	"From ROUND 2 SOAP Interoperability Tests Specification"
	"http://www.whitemesa.com/interop/proposal2.html#echoString"
	^ '<?xml version="1.0" encoding="UTF-8"?>

<SOAP-ENV:Envelope SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/" xmlns:SOAP-ENC="http://schemas.xmlsoap.org/soap/encoding/" xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
<SOAP-ENV:Body>
<m:echoString xmlns:m="http://soapinterop.org/">
<inputString>hello world</inputString>
</m:echoString>
</SOAP-ENV:Body>
</SOAP-ENV:Envelope>
'! !
